# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: scalekit/v1/organizations/organizations.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.api import visibility_pb2 as google_dot_api_dot_visibility__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from protoc_gen_openapiv2.options import annotations_pb2 as protoc__gen__openapiv2_dot_options_dot_annotations__pb2
from scalekit.v1.commons import commons_pb2 as scalekit_dot_v1_dot_commons_dot_commons__pb2
from scalekit.v1.options import options_pb2 as scalekit_dot_v1_dot_options_dot_options__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-scalekit/v1/organizations/organizations.proto\x12\x19scalekit.v1.organizations\x1a\x1b\x62uf/validate/validate.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1bgoogle/api/visibility.proto\x1a\x19google/protobuf/any.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a.protoc-gen-openapiv2/options/annotations.proto\x1a!scalekit/v1/commons/commons.proto\x1a!scalekit/v1/options/options.proto\"\xaf\x01\n\x19\x43reateOrganizationRequest\x12\x91\x01\n\x0corganization\x18\x01 \x01(\x0b\x32-.scalekit.v1.organizations.CreateOrganizationB>\x92\x41\x35\x32\x33Required parameters for creating a new organization\xbaH\x03\xc8\x01\x01R\x0corganization\"\xb9\x01\n\x1a\x43reateOrganizationResponse\x12\x9a\x01\n\x0corganization\x18\x01 \x01(\x0b\x32\'.scalekit.v1.organizations.OrganizationBM\x92\x41J2HThe newly created organization containing its ID, settings, and metadataR\x0corganization\"\xa0\x05\n\x12\x43reateOrganization\x12\x84\x01\n\x0c\x64isplay_name\x18\x04 \x01(\tBa\x92\x41Q2?Name of the organization. Must be between 1 and 200 characters.J\x0e\"Megasoft Inc\"\xe0\x41\x02\xbaH\x07r\x05\x10\x01\x18\xc8\x01R\x0b\x64isplayName\x12\xa0\x01\n\x0bregion_code\x18\x05 \x01(\x0e\x32\x1f.scalekit.v1.commons.RegionCodeB^\x92\x41L2DGeographic region code for the organization. Currently limited to USJ\x04\"US\"\xfa\xd2\xe4\x93\x02\t\x12\x07PREVIEWR\nregionCode\x12\x9e\x01\n\x0b\x65xternal_id\x18\x06 \x01(\tBx\x92\x41u2cYour application\'s unique identifier for this organization, used to link Scalekit with your system.J\x0e\"my_unique_id\"H\x00R\nexternalId\x88\x01\x01\x12r\n\x08metadata\x18\x07 \x03(\x0b\x32;.scalekit.v1.organizations.CreateOrganization.MetadataEntryB\x19\xbaH\x16\x9a\x01\x13\x10\n\"\x06r\x04\x10\x03\x18\x19*\x07r\x05\x10\x01\x18\x80\x02R\x08metadata\x1a;\n\rMetadataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\x0e\n\x0c_external_id\"\xe7\x08\n\x0cOrganization\x12{\n\x02id\x18\x01 \x01(\tBk\x92\x41h2MUnique scalekit-generated identifier that uniquely references an organizationJ\x17\"org_59615193906282635\"R\x02id\x12\x8c\x01\n\x0b\x63reate_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampBO\x92\x41I2+Timestamp when the organization was createdJ\x1a\"2025-02-15T06:23:44.560Z\"\xe0\x41\x02R\ncreateTime\x12\x8e\x01\n\x0bupdate_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampBQ\x92\x41N20Timestamp when the organization was last updatedJ\x1a\"2025-02-15T06:23:44.560Z\"R\nupdateTime\x12|\n\x0c\x64isplay_name\x18\x04 \x01(\tBY\x92\x41L2>Name of the organization. Must be between 1 and 200 charactersJ\n\"Megasoft\"\xbaH\x07r\x05\x10\x01\x18\xc8\x01R\x0b\x64isplayName\x12\x92\x01\n\x0bregion_code\x18\x05 \x01(\x0e\x32\x1f.scalekit.v1.commons.RegionCodeBP\x92\x41M2EGeographic region code for the organization. Currently limited to US.J\x04\"US\"R\nregionCode\x12\x9e\x01\n\x0b\x65xternal_id\x18\x06 \x01(\tBx\x92\x41u2cYour application\'s unique identifier for this organization, used to link Scalekit with your system.J\x0e\"my_unique_id\"H\x00R\nexternalId\x88\x01\x01\x12l\n\x08metadata\x18\x07 \x03(\x0b\x32\x35.scalekit.v1.organizations.Organization.MetadataEntryB\x19\xbaH\x16\x9a\x01\x13\x10\n\"\x06r\x04\x10\x03\x18\x19*\x07r\x05\x10\x01\x18\x80\x02R\x08metadata\x12K\n\x08settings\x18\x08 \x01(\x0b\x32/.scalekit.v1.organizations.OrganizationSettingsR\x08settings\x1a;\n\rMetadataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\x0e\n\x0c_external_id\"\xe0\x03\n\x19UpdateOrganizationRequest\x12j\n\x02id\x18\x01 \x01(\tBX\x92\x41L23Unique identifier of the organization to be updatedJ\x15\"org_121312434123312\"\xbaH\x06r\x04\x10\x01\x18 H\x00R\x02id\x12\x85\x01\n\x0b\x65xternal_id\x18\x02 \x01(\tBb\x92\x41I2-External ID of the organization to be updatedJ\x18\"tenant_123123123123123\"\xbaH\x04r\x02\x10\x01\xfa\xd2\xe4\x93\x02\t\x12\x07PREVIEWH\x00R\nexternalId\x12\x83\x01\n\x0corganization\x18\x03 \x01(\x0b\x32-.scalekit.v1.organizations.UpdateOrganizationB0\x92\x41\'2%Organization Parameters to be updated\xbaH\x03\xc8\x01\x01R\x0corganization\x12;\n\x0bupdate_mask\x18\x63 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskR\nupdateMaskB\x0c\n\nidentities\"\xe1\x05\n\x12UpdateOrganization\x12\x9e\x01\n\x0c\x64isplay_name\x18\x04 \x01(\tBv\x92\x41i2SName of the organization to display in the UI. Must be between 1 and 200 charactersJ\x12\"Acme Corporation\"\xbaH\x07r\x05\x10\x01\x18\xc8\x01H\x00R\x0b\x64isplayName\x88\x01\x01\x12\x9d\x01\n\x0b\x65xternal_id\x18\x06 \x01(\tBw\x92\x41t2bYour application\'s unique identifier for this organization, used to link Scalekit with your systemJ\x0e\"tenant_12345\"H\x01R\nexternalId\x88\x01\x01\x12\xa5\x02\n\x08metadata\x18\x07 \x03(\x0b\x32;.scalekit.v1.organizations.UpdateOrganization.MetadataEntryB\xcb\x01\x92\x41\xae\x01\x32\x8f\x01\x43ustom key-value pairs to store with the organization. Keys must be 3-25 characters, values must be 1-256 characters. Maximum 10 pairs allowed.J\x1a{\"industry\": \"technology\"}\xbaH\x16\x9a\x01\x13\x10\n\"\x06r\x04\x10\x03\x18\x19*\x07r\x05\x10\x01\x18\x80\x02R\x08metadata\x1a;\n\rMetadataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\x0f\n\r_display_nameB\x0e\n\x0c_external_idJ\x04\x08\x05\x10\x06\"\x8c\x01\n\x1aUpdateOrganizationResponse\x12n\n\x0corganization\x18\x01 \x01(\x0b\x32\'.scalekit.v1.organizations.OrganizationB!\x92\x41\x1e\x32\x1cUpdated organization detailsR\x0corganization\"\xeb\x02\n\x16GetOrganizationRequest\x12\x84\x01\n\x02id\x18\x01 \x01(\tBr\x92\x41\x66\x32MUnique scalekit-generated identifier that uniquely references an organizationJ\x15\"org_121312434123312\"\xbaH\x06r\x04\x10\x01\x18 H\x00R\x02id\x12\xbb\x01\n\x0b\x65xternal_id\x18\x02 \x01(\tB\x97\x01\x92\x41~2bUnique identifier that links an Organization Object to your app\'s tenant, stored as an External IDJ\x18\"tenant_123123123123123\"\xbaH\x04r\x02\x10\x01\xfa\xd2\xe4\x93\x02\t\x12\x07PREVIEWH\x00R\nexternalIdB\x0c\n\nidentities\"\x8b\x01\n\x17GetOrganizationResponse\x12p\n\x0corganization\x18\x01 \x01(\x0b\x32\'.scalekit.v1.organizations.OrganizationB#\x92\x41 2\x1eThe newly created organizationR\x0corganization\"\xe0\x05\n\x18ListOrganizationsRequest\x12t\n\tpage_size\x18\x01 \x01(\rBW\x92\x41T2NMaximum number of organizations to return per page. Must be between 10 and 100J\x02\x33\x30R\x08pageSize\x12\x8f\x01\n\npage_token\x18\x02 \x01(\tBp\x92\x41m2[Pagination token from the previous response. Use to retrieve the next page of organizationsJ\x0e\"<page_token>\"R\tpageToken\x12\xa8\x01\n\x0b\x65xternal_id\x18\x03 \x01(\tB\x81\x01\x92\x41~2bYour application\'s unique identifier for this organization, used to link Scalekit with your systemJ\x18\"<your_app_assigned_id>\"H\x00R\nexternalId\x88\x01\x01:\x80\x02\x92\x41\xfc\x01\n\xab\x01*\x12List Organizations2\x94\x01Retrieves a paginated list of all organizations within the environment. Use the `page_token` from the response to access subsequent pages of results*L\n\x12List Organizations\x12\x36https://docs.scalekit.com/reference/list-organizationsB\x0e\n\x0c_external_id\"\xa4\x04\n\x19ListOrganizationsResponse\x12\x97\x01\n\x0fnext_page_token\x18\x01 \x01(\tBo\x92\x41l2UPagination token for the next page of results. Use this token to fetch the next page.J\x13\"<next_page_token>\"R\rnextPageToken\x12Y\n\ntotal_size\x18\x02 \x01(\rB:\x92\x41\x37\x32\x31Total number of organizations in the environment.J\x02\x33\x30R\ttotalSize\x12p\n\rorganizations\x18\x03 \x03(\x0b\x32\'.scalekit.v1.organizations.OrganizationB!\x92\x41\x1e\x32\x1cList of organization objectsR\rorganizations\x12\x9f\x01\n\x0fprev_page_token\x18\x04 \x01(\tBw\x92\x41t2]Pagination token for the previous page of results. Use this token to fetch the previous page.J\x13\"<prev_page_token>\"R\rprevPageToken\"\xa7\x05\n\x1aSearchOrganizationsRequest\x12\xa5\x01\n\x05query\x18\x01 \x01(\tB\x8e\x01\x92\x41\x7f\x32wSearch term to match against organization names, IDs, or external IDs. Must be at least 3 characters. Case insensitive.J\x04\x61\x63me\xbaH\tr\x04\x10\x03\x18\x64\xc8\x01\x01R\x05query\x12\x80\x01\n\tpage_size\x18\x02 \x01(\rBc\x92\x41Y2SMaximum number of organizations to return per page. Value must be between 1 and 30.J\x02\x33\x30\xbaH\x04*\x02\x18\x1eR\x08pageSize\x12\xa5\x01\n\npage_token\x18\x03 \x01(\tB\x85\x01\x92\x41\x81\x01\x32\x61Token from a previous response for pagination. Provide this to retrieve the next page of results.J\x1c\x65yJwYWdlIjoyLCJsaW1pdCI6MzB9R\tpageToken:\xb5\x01\x92\x41\xb1\x01\n\x88\x01*\x14Search Organizations2pSearch for organizations in your environment using a text query that matches against names, IDs, or external IDs2$query=acme&page_size=30&page_token=1\"\xdb\x01\n\x1bSearchOrganizationsResponse\x12&\n\x0fnext_page_token\x18\x01 \x01(\tR\rnextPageToken\x12\x1d\n\ntotal_size\x18\x02 \x01(\rR\ttotalSize\x12M\n\rorganizations\x18\x03 \x03(\x0b\x32\'.scalekit.v1.organizations.OrganizationR\rorganizations\x12&\n\x0fprev_page_token\x18\x04 \x01(\tR\rprevPageToken\"\xad\x02\n\x19\x44\x65leteOrganizationRequest\x12~\n\x02id\x18\x01 \x01(\tBl\x92\x41`2MUnique scalekit-generated identifier that uniquely references an organizationJ\x0f\"org_123456789\"\xbaH\x06r\x04\x10\x01\x18 H\x00R\x02id\x12\x81\x01\n\x0b\x65xternal_id\x18\x02 \x01(\tB^\x92\x41\x45\x32)External ID of the organization to deleteJ\x18\"tenant_123123123123123\"\xbaH\x04r\x02\x10\x01\xfa\xd2\xe4\x93\x02\t\x12\x07PREVIEWH\x00R\nexternalIdB\x0c\n\nidentities\"\xcf\x04\n\x19GeneratePortalLinkRequest\x12N\n\x02id\x18\x01 \x01(\tB>\x92\x41)2\x0fOrganization IDJ\x16\"org_1231234233424344\"\xbaH\x0fr\n\x10\x01\x18 :\x04org_\xc8\x01\x01R\x02id\x12(\n\x03sso\x18\x02 \x01(\x08\x42\x11\x18\x01\xfa\xd2\xe4\x93\x02\t\x12\x07PREVIEWH\x00R\x03sso\x88\x01\x01\x12=\n\x0e\x64irectory_sync\x18\x03 \x01(\x08\x42\x11\x18\x01\xfa\xd2\xe4\x93\x02\t\x12\x07PREVIEWH\x01R\rdirectorySync\x88\x01\x01\x12\xdd\x02\n\x08\x66\x65\x61tures\x18\x04 \x03(\x0e\x32\".scalekit.v1.organizations.FeatureB\x9c\x02\x92\x41\x98\x02\x32\x95\x02\x46\x65\x61tures to enable in the admin portal link. To enable features, append them as URL parameters:\n\n- Single Sign-On: ?features=sso\n- Directory Sync: ?features=dir_sync\n- Both features: ?features=sso&features=dir_sync\n\nExample URL: https://scalekit.com/portal/lnk_123?features=ssoR\x08\x66\x65\x61turesB\x06\n\x04_ssoB\x11\n\x0f_directory_sync\"f\n\x14GetPortalLinkRequest\x12N\n\x02id\x18\x01 \x01(\tB>\x92\x41)2\x0fOrganization IDJ\x16\"org_1231234233424344\"\xbaH\x0fr\n\x10\x01\x18 :\x04org_\xc8\x01\x01R\x02id\"i\n\x17\x44\x65letePortalLinkRequest\x12N\n\x02id\x18\x01 \x01(\tB>\x92\x41)2\x0fOrganization IDJ\x16\"org_1231234233424344\"\xbaH\x0fr\n\x10\x01\x18 :\x04org_\xc8\x01\x01R\x02id\"\xbe\x01\n\x1b\x44\x65letePortalLinkByIdRequest\x12N\n\x02id\x18\x01 \x01(\tB>\x92\x41)2\x0fOrganization IDJ\x16\"org_1231234233424344\"\xbaH\x0fr\n\x10\x01\x18 :\x04org_\xc8\x01\x01R\x02id\x12O\n\x07link_id\x18\x02 \x01(\tB6\x92\x41!2\x07Link IDJ\x16\"lnk_1231234233424344\"\xbaH\x0fr\n\x10\x01\x18 :\x04lnk_\xc8\x01\x01R\x06linkId\"\xb2\x03\n\x04Link\x12J\n\x02id\x18\x01 \x01(\tB:\x92\x41\x37\x32\x1eUnique Identifier for the linkJ\x15\"lnk_123123123123123\"R\x02id\x12\xc6\x01\n\x08location\x18\x02 \x01(\tB\xa9\x01\x92\x41\xa5\x01\x32pLocation of the link. This is the URL that can be used to access the Admin portal. The link is valid for 1 week.J1\"https://scalekit.com/portal/lnk_123123123123123\"R\x08location\x12\x94\x01\n\x0b\x65xpire_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampBW\x92\x41T26Expiry time of the link. The link is valid for 1 week.J\x1a\"2024-02-06T14:48:00.000Z\"R\nexpireTime\"\x96\x02\n\x1aGeneratePortalLinkResponse\x12\xf7\x01\n\x04link\x18\x01 \x01(\x0b\x32\x1f.scalekit.v1.organizations.LinkB\xc1\x01\x92\x41\xbd\x01\x32\xba\x01\x43ontains the generated admin portal link details. The link URL can be shared with organization administrators to set up: Single Sign-On (SSO) authentication and directory synchronizationR\x04link\"h\n\x16GetPortalLinksResponse\x12N\n\x05links\x18\x01 \x03(\x0b\x32\x1f.scalekit.v1.organizations.LinkB\x17\x92\x41\x14\x32\x12\x41\x64min Portal LinksR\x05links\"\x90\x04\n!UpdateOrganizationSettingsRequest\x12\x97\x01\n\x02id\x18\x01 \x01(\tB\x86\x01\x92\x41q2WUnique identifier of the organization to update settings. Must begin with \'org_\' prefixJ\x16\"org_1231234233424344\"\xbaH\x0fr\n\x10\x01\x18 :\x04org_\xc8\x01\x01R\x02id\x12\xd0\x02\n\x08settings\x18\x02 \x01(\x0b\x32/.scalekit.v1.organizations.OrganizationSettingsB\x82\x02\x92\x41\xf8\x01\x32\x95\x01Settings configuration to apply to the organization. Contains feature toggles for SSO, directory synchronization, and other organization capabilitiesJ^{\"features\": [{\"name\": \"sso\", \"enabled\": true}, {\"name\": \"directory_sync\", \"enabled\": false}]}\xbaH\x03\xc8\x01\x01R\x08settings\"\xee\x04\n(UpdateOrganizationSessionSettingsRequest\x12\x84\x01\n\x02id\x18\x01 \x01(\tBt\x92\x41\x63\x32HUnique identifier for the organization, beginning with an \'org_\' prefix.J\x17\"org_59615193906282635\"\xbaH\x0br\t\x10\x01\x18 :\x03orgR\x02id\x12\xf2\x01\n\x0e\x65nvironment_id\x18\x02 \x01(\tB\xca\x01\x92\x41\xb8\x01\x32\x9c\x01Unique identifier for the environment where the organization resides, prefixed with \'env_\'. This specifies the environment context for the session settings.J\x17\"env_59615193906282635\"\xbaH\x0br\t\x10\x01\x18 :\x03\x65nvR\renvironmentId\x12\xc5\x01\n\x10session_settings\x18\x03 \x01(\x0b\x32\x36.scalekit.v1.organizations.OrganizationSessionSettingsBb\x92\x41Y2WThe session settings to be applied, including absolute and idle timeout configurations.\xbaH\x03\xc8\x01\x01R\x0fsessionSettings\"\x82\x04\n)UpdateOrganizationSessionSettingsResponse\x12\x8f\x01\n\x0e\x65nvironment_id\x18\x01 \x01(\tBh\x92\x41\x65\x32JThe environment ID where the organization\'s session settings were updated.J\x17\"env_59615193906282635\"R\renvironmentId\x12\x95\x01\n\x0forganization_id\x18\x02 \x01(\tBl\x92\x41i2NThe unique identifier of the organization whose session settings were updated.J\x17\"org_59615193906282635\"R\x0eorganizationId\x12\xaa\x01\n\x10session_settings\x18\x03 \x01(\x0b\x32\x36.scalekit.v1.organizations.OrganizationSessionSettingsBG\x92\x41\x44\x32\x42The updated session settings, reflecting the new timeout policies.R\x0fsessionSettings\"\xbf\x05\n\"OrganizationUserManagementSettings\x12\xe9\x01\n!jit_provisioning_with_sso_enabled\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValueB\x82\x01\x92\x41\x7f\x32wEnables or disables user management features for the organization. When true, users can be added, removed, and managed.J\x04trueR\x1djitProvisioningWithSsoEnabled\x12\x95\x02\n\x1bsync_user_profile_on_signin\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.BoolValueB\xba\x01\x92\x41\xb6\x01\x32\xad\x01\x45nables or disables synchronization of user profiles upon sign-in. When true, user profiles are automatically updated with the latest information from the identity provider.J\x04trueR\x17syncUserProfileOnSignin\x12\x94\x01\n\x16\x64\x65precated_placeholder\x18\x63 \x01(\x0e\x32\x1a.google.protobuf.NullValueBA\x18\x01\x92\x41-2+Deprecated placeholder (no functional use).\xfa\xd2\xe4\x93\x02\t\x12\x07PREVIEWR\x15\x64\x65precatedPlaceholder\"\xad\x07\n\x1bOrganizationSessionSettings\x12\xfe\x01\n\x18\x61\x62solute_session_timeout\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int32ValueB\xa6\x01\x92\x41\xa2\x01\x32\x98\x01The maximum duration in seconds that a session can remain active, regardless of activity. After this time, the user will be required to re-authenticate.J\x05\x38\x36\x34\x30\x30R\x16\x61\x62soluteSessionTimeout\x12\xdd\x01\n\x1asession_management_enabled\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.BoolValueB\x82\x01\x92\x41\x7f\x32wEnables or disables session management features for the organization. When true, session timeout policies are enforced.J\x04trueR\x18sessionManagementEnabled\x12\xd4\x01\n\x14idle_session_timeout\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int32ValueB\x84\x01\x92\x41\x80\x01\x32xThe duration in seconds that a session can remain idle before it is automatically terminated. Activity resets the timer.J\x04\x31\x38\x30\x30R\x12idleSessionTimeout\x12\xd5\x01\n\x14idle_session_enabled\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.BoolValueB\x86\x01\x92\x41\x82\x01\x32zEnables or disables idle session timeout. If true, inactive sessions will be terminated after the specified idle duration.J\x04trueR\x12idleSessionEnabled\"\x82\x03\n%GetOrganizationSessionSettingsRequest\x12\x92\x01\n\x02id\x18\x01 \x01(\tB\x81\x01\x92\x41p2UThe unique identifier of the organization whose session settings are being requested.J\x17\"org_59615193906282635\"\xbaH\x0br\t\x10\x01\x18 :\x03orgR\x02id\x12\xc3\x01\n\x0e\x65nvironment_id\x18\x02 \x01(\tB\x9b\x01\x92\x41\x89\x01\x32nThe environment ID to scope the request. This ensures the settings are retrieved from the correct environment.J\x17\"env_59615193906282635\"\xbaH\x0br\t\x10\x01\x18 :\x03\x65nvR\renvironmentId\"\x89\x03\n(CreateOrganizationSessionSettingsRequest\x12\x8b\x01\n\x02id\x18\x01 \x01(\tB{\x92\x41j2OThe unique identifier of the organization for which to create session settings.J\x17\"org_59615193906282635\"\xbaH\x0br\t\x10\x01\x18 :\x03orgR\x02id\x12\xce\x01\n\x0e\x65nvironment_id\x18\x02 \x01(\tB\xa6\x01\x92\x41\x94\x01\x32yThe environment ID where the organization exists. This scopes the creation of session settings to a specific environment.J\x17\"env_59615193906282635\"\xbaH\x0br\t\x10\x01\x18 :\x03\x65nvR\renvironmentId\"\xf4\x03\n)CreateOrganizationSessionSettingsResponse\x12\x80\x01\n\x0e\x65nvironment_id\x18\x01 \x01(\tBY\x92\x41V2;The environment ID where the session settings were created.J\x17\"env_59615193906282635\"R\renvironmentId\x12\x99\x01\n\x0forganization_id\x18\x02 \x01(\tBp\x92\x41m2RThe unique identifier of the organization for which session settings were created.J\x17\"org_59615193906282635\"R\x0eorganizationId\x12\xa7\x01\n\x10session_settings\x18\x03 \x01(\x0b\x32\x36.scalekit.v1.organizations.OrganizationSessionSettingsBD\x92\x41\x41\x32?The newly created session settings, including timeout policies.R\x0fsessionSettings\"\xf1\x03\n&GetOrganizationSessionSettingsResponse\x12\x87\x01\n\x0e\x65nvironment_id\x18\x01 \x01(\tB`\x92\x41]2BThe environment ID from which the session settings were retrieved.J\x17\"env_59615193906282635\"R\renvironmentId\x12\x95\x01\n\x0forganization_id\x18\x02 \x01(\tBl\x92\x41i2NThe unique identifier of the organization whose session settings are returned.J\x17\"org_59615193906282635\"R\x0eorganizationId\x12\xa4\x01\n\x10session_settings\x18\x03 \x01(\x0b\x32\x36.scalekit.v1.organizations.OrganizationSessionSettingsBA\x92\x41>2<The retrieved session timeout policies for the organization.R\x0fsessionSettings\"\x8e\x03\n(DeleteOrganizationSessionSettingsRequest\x12\x8f\x01\n\x02id\x18\x01 \x01(\tB\x7f\x92\x41n2SThe unique identifier of the organization whose session settings should be deleted.J\x17\"org_59615193906282635\"\xbaH\x0br\t\x10\x01\x18 :\x03orgR\x02id\x12\xcf\x01\n\x0e\x65nvironment_id\x18\x02 \x01(\tB\xa7\x01\x92\x41\x95\x01\x32zThe environment ID to scope the deletion. This ensures that the session settings are removed from the correct environment.J\x17\"env_59615193906282635\"\xbaH\x0br\t\x10\x01\x18 :\x03\x65nvR\renvironmentId\"\x8e\x04\n\x14OrganizationSettings\x12\xa4\x02\n\x08\x66\x65\x61tures\x18\x01 \x03(\x0b\x32\x36.scalekit.v1.organizations.OrganizationSettingsFeatureB\xcf\x01\x92\x41\xcb\x01\x32wList of feature toggles that control organization capabilities such as SSO authentication and directory synchronizationJP[{\"name\": \"sso\", \"enabled\": true}, {\"name\": \"directory_sync\", \"enabled\": false}]R\x08\x66\x65\x61tures:\xce\x01\x92\x41\xca\x01\nh*\x15Organization Settings2OConfiguration options that control organization-level features and capabilities2^{\"features\": [{\"name\": \"sso\", \"enabled\": true}, {\"name\": \"directory_sync\", \"enabled\": false}]}\"\x9f\x03\n\x1bOrganizationSettingsFeature\x12\x92\x01\n\x04name\x18\x01 \x01(\tB~\x92\x41{2rFeature identifier. Supported values include: \"sso\" (Single Sign-On), \"directory_sync\" (Directory Synchronization)J\x05\"sso\"R\x04name\x12t\n\x07\x65nabled\x18\x02 \x01(\x08\x42Z\x92\x41W2OWhether the feature is enabled (true) or disabled (false) for this organizationJ\x04trueR\x07\x65nabled:u\x92\x41r\np*\x1bOrganization Feature Toggle2@Controls the activation state of a specific organization feature\xd2\x01\x04name\xd2\x01\x07\x65nabled\"\x96\x02\n#UpdateUserManagementSettingsRequest\x12W\n\x0forganization_id\x18\x01 \x01(\tB.\x92\x41\x19\x32\x17ID of the organization.\xbaH\x0fr\n\x10\x01\x18 :\x04org_\xc8\x01\x01R\x0eorganizationId\x12\x95\x01\n\x08settings\x18\x02 \x01(\x0b\x32=.scalekit.v1.organizations.OrganizationUserManagementSettingsB:\x92\x41\x31\x32/The new values for the setting fields to patch.\xbaH\x03\xc8\x01\x01R\x08settings\"\x9c\x01\n$UpdateUserManagementSettingsResponse\x12t\n\x08settings\x18\x01 \x01(\x0b\x32=.scalekit.v1.organizations.OrganizationUserManagementSettingsB\x19\x92\x41\x16\x32\x14The updated setting.R\x08settings\"\x87\x01\n,GetOrganizationUserManagementSettingsRequest\x12W\n\x0forganization_id\x18\x01 \x01(\tB.\x92\x41\x19\x32\x17ID of the organization.\xbaH\x0fr\n\x10\x01\x18 :\x04org_\xc8\x01\x01R\x0eorganizationId\"\xaf\x01\n-GetOrganizationUserManagementSettingsResponse\x12~\n\x08settings\x18\x01 \x01(\x0b\x32=.scalekit.v1.organizations.OrganizationUserManagementSettingsB#\x92\x41 2\x1eList of organization settings.R\x08settings*R\n\x07\x46\x65\x61ture\x12\x17\n\x13\x46\x45\x41TURE_UNSPECIFIED\x10\x00\x12\x13\n\x0bUNSPECIFIED\x10\x00\x1a\x02\x08\x01\x12\x0c\n\x08\x64ir_sync\x10\x01\x12\x07\n\x03sso\x10\x02\x1a\x02\x10\x01\x32\xd4\x82\x01\n\x13OrganizationService\x12\xef\n\n\x12\x43reateOrganization\x12\x34.scalekit.v1.organizations.CreateOrganizationRequest\x1a\x35.scalekit.v1.organizations.CreateOrganizationResponse\"\xeb\t\x92\x41\xb6\t\n\rOrganizations\x12\x16\x43reate an organization\x1a\x8f\x01\x43reates a new organization in your environment. Use this endpoint to add a new tenant that can be configured with various settings and metadataJ\x93\x01\n\x03\x32\x30\x31\x12\x8b\x01\nNReturns the newly created organization with its unique identifier and settings\x12\x39\n7\x1a\x35.scalekit.v1.organizations.CreateOrganizationResponsej\xe4\x06\n\rx-codeSamples\x12\xd2\x06\x32\xcf\x06\n\xa4\x01*\xa1\x01\n\x16\n\x05label\x12\r\x1a\x0bNode.js SDK\n\x14\n\x04lang\x12\x0c\x1a\njavascript\nq\n\x06source\x12g\x1a\x65\x63onst organization = await sc.organization.createOrganization(name, {\n  externalId: \'externalId\',\n});\n\xd5\x01*\xd2\x01\n\x15\n\x05label\x12\x0c\x1a\nPython SDK\n\x10\n\x04lang\x12\x08\x1a\x06python\n\xa6\x01\n\x06source\x12\x9b\x01\x1a\x98\x01options = CreateOrganizationOptions()\noptions.external_id = \"externalId\"\norganization = sc.organization.create_organization(\n  name,\n  options=options\n)\n\xc7\x01*\xc4\x01\n\x11\n\x05label\x12\x08\x1a\x06Go SDK\n\x0c\n\x04lang\x12\x04\x1a\x02go\n\xa0\x01\n\x06source\x12\x95\x01\x1a\x92\x01organization, err := sc.Organization.CreateOrganization(\n  ctx,\n  name,\n  scalekit.CreateOrganizationOptions{\n    ExternalID: \"externalId\",\n  },\n)\n\x83\x02*\x80\x02\n\x13\n\x05label\x12\n\x1a\x08Java SDK\n\x0e\n\x04lang\x12\x06\x1a\x04java\n\xd8\x01\n\x06source\x12\xcd\x01\x1a\xca\x01\x43reateOrganization createOrganization = CreateOrganization.newBuilder().setDisplayName(\"Test Org\").build();\n\nOrganization createdOrganization = scalekitClient.organizations().create(createOrganization);\x82\xb5\x18\x02\x18T\x82\xd3\xe4\x93\x02%\"\x15/api/v1/organizations:\x0corganization\x12\xfd\x0b\n\x12UpdateOrganization\x12\x34.scalekit.v1.organizations.UpdateOrganizationRequest\x1a\x35.scalekit.v1.organizations.UpdateOrganizationResponse\"\xf9\n\x92\x41\xbf\n\n\rOrganizations\x12\x1bUpdate organization details\x1a\xa1\x01Updates an organization\'s display name, external ID, or metadata. Requires a valid organization identifier. Region code cannot be modified through this endpoint.J\x99\x01\n\x03\x32\x30\x30\x12\x91\x01\nTReturns the updated organization with all current details reflected in the response.\x12\x39\n7\x1a\x35.scalekit.v1.organizations.UpdateOrganizationResponsej\xd0\x07\n\rx-codeSamples\x12\xbe\x07\x32\xbb\x07\n\xd0\x01*\xcd\x01\n\x16\n\x05label\x12\r\x1a\x0bNode.js SDK\n\x14\n\x04lang\x12\x0c\x1a\njavascript\n\x9c\x01\n\x06source\x12\x91\x01\x1a\x8e\x01\x63onst organization = await sc.organization.updateOrganization(organization_id, {\n  displayName: \'displayName\',\n  externalId: \'externalId\',\n});\n\xc2\x01*\xbf\x01\n\x15\n\x05label\x12\x0c\x1a\nPython SDK\n\x10\n\x04lang\x12\x08\x1a\x06python\n\x93\x01\n\x06source\x12\x88\x01\x1a\x85\x01organization = sc.organization.update_organization(organization_id, {\n  display_name: \"display_name\",\n  external_id: \"external_id\"\n})\n\xeb\x01*\xe8\x01\n\x11\n\x05label\x12\x08\x1a\x06Go SDK\n\x0c\n\x04lang\x12\x04\x1a\x02go\n\xc4\x01\n\x06source\x12\xb9\x01\x1a\xb6\x01organization, err := sc.Organization.UpdateOrganization(\n  ctx,\n  organizationId,\n  &scalekit.UpdateOrganization{\n    DisplayName: \"displayName\",\n    ExternalId: \"externalId\",\n  },\n)\n\xb2\x02*\xaf\x02\n\x13\n\x05label\x12\n\x1a\x08Java SDK\n\x0e\n\x04lang\x12\x06\x1a\x04java\n\x87\x02\n\x06source\x12\xfc\x01\x1a\xf9\x01UpdateOrganization updateOrganization = UpdateOrganization.newBuilder()\n  .setDisplayName(\"Updated Organization Name\")\n  .build();\n\nOrganization updatedOrganizationById = scalekitClient.organizations().updateById(organizationId, updateOrganization);\x82\xb5\x18\x02\x18T\x82\xd3\xe4\x93\x02*2\x1a/api/v1/organizations/{id}:\x0corganization\x12\xef\x0b\n\x0fGetOrganization\x12\x31.scalekit.v1.organizations.GetOrganizationRequest\x1a\x32.scalekit.v1.organizations.GetOrganizationResponse\"\xf4\n\x92\x41\xc8\n\n\rOrganizations\x12\x18Get organization details\x1a]Retrieves organization details by Scalekit ID, including name, region, metadata, and settingsJ\x98\x01\n\x03\x32\x30\x30\x12\x90\x01\nVReturns the complete organization object with ID, display name, settings, and metadata\x12\x36\n4\x1a\x32.scalekit.v1.organizations.GetOrganizationResponsej\xa2\x08\n\rx-codeSamples\x12\x90\x08\x32\x8d\x08\n\x82\x02*\xff\x01\n\x16\n\x05label\x12\r\x1a\x0bNode.js SDK\n\x14\n\x04lang\x12\x0c\x1a\njavascript\n\xce\x01\n\x06source\x12\xc3\x01\x1a\xc0\x01\x63onst sc = new ScalekitClient(\n  <SCALEKIT_ENVIRONMENT_URL>,\n  <SCALEKIT_CLIENT_ID>,\n  <SCALEKIT_CLIENT_SECRET>\n);\n\nconst organization = await sc.organization.getOrganization(organization_id);\n\xea\x01*\xe7\x01\n\x15\n\x05label\x12\x0c\x1a\nPython SDK\n\x10\n\x04lang\x12\x08\x1a\x06python\n\xbb\x01\n\x06source\x12\xb0\x01\x1a\xad\x01sc = ScalekitClient(\n  <SCALEKIT_ENVIRONMENT_URL>,\n  <SCALEKIT_CLIENT_ID>,\n  <SCALEKIT_CLIENT_SECRET>\n)\n\norganization = sc.organization.get_organization(\n  organization_id\n)\n\xfa\x01*\xf7\x01\n\x11\n\x05label\x12\x08\x1a\x06Go SDK\n\x0c\n\x04lang\x12\x04\x1a\x02go\n\xd3\x01\n\x06source\x12\xc8\x01\x1a\xc5\x01sc := scalekit.NewScalekitClient(\n  <SCALEKIT_ENVIRONMENT_URL>,\n  <SCALEKIT_CLIENT_ID>,\n  <SCALEKIT_CLIENT_SECRET>\n)\n\norganization, err := sc.Organization.GetOrganization(\n  ctx,\n  organizationId\n)\n\x9b\x02*\x98\x02\n\x13\n\x05label\x12\n\x1a\x08Java SDK\n\x0e\n\x04lang\x12\x06\x1a\x04java\n\xf0\x01\n\x06source\x12\xe5\x01\x1a\xe2\x01ScalekitClient scalekitClient = new ScalekitClient(\n  \"<SCALEKIT_ENVIRONMENT_URL>\",\n  \"<SCALEKIT_CLIENT_ID>\",\n  \"<SCALEKIT_CLIENT_SECRET>\"\n);\n\nOrganization organization = scalekitClient.organizations().getById(organizationId);\x82\xb5\x18\x02\x18t\x82\xd3\xe4\x93\x02\x1c\x12\x1a/api/v1/organizations/{id}\x12\x87\n\n\x10ListOrganization\x12\x33.scalekit.v1.organizations.ListOrganizationsRequest\x1a\x34.scalekit.v1.organizations.ListOrganizationsResponse\"\x87\t\x92\x41\xe0\x08\n\rOrganizations\x12\x12List organizations\x1a\xa0\x01Retrieve a paginated list of organizations within your environment. The response includes a `page_token` that can be used to access subsequent pages of results.\"C\n%Learn more about organization listing\x12\x1ahttps://docs.scalekit.com/Js\n\x03\x32\x30\x30\x12l\n0Successfully retrieved the list of organizations\x12\x38\n6\x1a\x34.scalekit.v1.organizations.ListOrganizationsResponseJ\x1b\n\x03\x34\x30\x30\x12\x14\n\x12Invalid page tokenj\xc0\x05\n\rx-codeSamples\x12\xae\x05\x32\xab\x05\n\x97\x01*\x94\x01\n\x16\n\x05label\x12\r\x1a\x0bNode.js SDK\n\x14\n\x04lang\x12\x0c\x1a\njavascript\nd\n\x06source\x12Z\x1aXconst organizations = await scalekit.organization.listOrganization({\n  pageSize: 10,\n});\n\xc0\x01*\xbd\x01\n\x15\n\x05label\x12\x0c\x1a\nPython SDK\n\x10\n\x04lang\x12\x08\x1a\x06python\n\x91\x01\n\x06source\x12\x86\x01\x1a\x83\x01options = ListOrganizationOptions()\noptions.page_size = 10\n\norganizations = sc.organization.list_organizations(\n  options=options\n)\n\xaf\x01*\xac\x01\n\x11\n\x05label\x12\x08\x1a\x06Go SDK\n\x0c\n\x04lang\x12\x04\x1a\x02go\n\x88\x01\n\x06source\x12~\x1a|organizations, err := sc.Organization.ListOrganizations(\n  ctx,\n  &scalekit.ListOrganizationOptions{\n    PageSize: 10,\n  }\n)\n\x99\x01*\x96\x01\n\x13\n\x05label\x12\n\x1a\x08Java SDK\n\x0e\n\x04lang\x12\x06\x1a\x04java\no\n\x06source\x12\x65\x1a\x63ListOrganizationsResponse organizations = scalekitClient.organizations().listOrganizations(10, \"\");\x82\xb5\x18\x02\x18T\x82\xd3\xe4\x93\x02\x17\x12\x15/api/v1/organizations\x12\xf1\x04\n\x12SearchOrganization\x12\x35.scalekit.v1.organizations.SearchOrganizationsRequest\x1a\x36.scalekit.v1.organizations.SearchOrganizationsResponse\"\xeb\x03\x92\x41\xae\x03\n\rOrganizations\x12\x14Search organizations\x1a\xd4\x01Searches for organizations in your environment using a query string. The query matches against organization name, ID, or external ID. Returns multiple results when more than one organization matches the criteria.J\xaf\x01\n\x03\x32\x30\x30\x12\xa7\x01\niReturns a list of matching organizations and a page token for pagination if there are additional results.\x12:\n8\x1a\x36.scalekit.v1.organizations.SearchOrganizationsResponse\x82\xb5\x18\x02\x18T\xfa\xd2\xe4\x93\x02\t\x12\x07PREVIEW\x82\xd3\xe4\x93\x02\x1e\x12\x1c/api/v1/organizations:search\x12\xcb\x07\n\x12\x44\x65leteOrganization\x12\x34.scalekit.v1.organizations.DeleteOrganizationRequest\x1a\x16.google.protobuf.Empty\"\xe6\x06\x92\x41\xba\x06\n\rOrganizations\x12\x16\x44\x65lete an organization\x1aPRemove an existing organization from the environment using its unique identifierJC\n\x03\x32\x30\x30\x12<\n:Organization successfully deleted and no longer accessiblej\xf9\x04\n\rx-codeSamples\x12\xe7\x04\x32\xe4\x04\nw*u\n\x16\n\x05label\x12\r\x1a\x0bNode.js SDK\n\x14\n\x04lang\x12\x0c\x1a\njavascript\nE\n\x06source\x12;\x1a\x39\x61wait sc.organization.deleteOrganization(organizationId);\nm*k\n\x15\n\x05label\x12\x0c\x1a\nPython SDK\n\x10\n\x04lang\x12\x08\x1a\x06python\n@\n\x06source\x12\x36\x1a\x34sc.organization.delete_organization(organization_id)\nu*s\n\x11\n\x05label\x12\x08\x1a\x06Go SDK\n\x0c\n\x04lang\x12\x04\x1a\x02go\nP\n\x06source\x12\x46\x1a\x44\x65rr := sc.Organization.DeleteOrganization(\n  ctx,\n  organizationId\n)\n\x82\x02*\xff\x01\n\x13\n\x05label\x12\n\x1a\x08Java SDK\n\x0e\n\x04lang\x12\x06\x1a\x04java\n\xd7\x01\n\x06source\x12\xcc\x01\x1a\xc9\x01ScalekitClient scalekitClient = new ScalekitClient(\n  \"<SCALEKIT_ENVIRONMENT_URL>\",\n  \"<SCALEKIT_CLIENT_ID>\",\n  \"<SCALEKIT_CLIENT_SECRET>\"\n);\n\nscalekitClient.organizations().deleteById(organizationId);\x82\xb5\x18\x02\x18T\x82\xd3\xe4\x93\x02\x1c*\x1a/api/v1/organizations/{id}\x12\xa4\t\n\x12GeneratePortalLink\x12\x34.scalekit.v1.organizations.GeneratePortalLinkRequest\x1a\x35.scalekit.v1.organizations.GeneratePortalLinkResponse\"\xa0\x08\x92\x41\xe7\x07\n\rOrganizations\x12\x1aGenerate admin portal link\x1a\xc2\x01\x43reates a time-limited Admin Portal URL for IT administrators to configure and manage Single Sign-On (SSO) connections within their organization. Generated links expire after 7 days (168 hours).J\x9f\x01\n\x03\x32\x30\x30\x12\x97\x01\nZAdmin Portal link generated successfully. Returns the portal URL and expiration timestamp.\x12\x39\n7\x1a\x35.scalekit.v1.organizations.GeneratePortalLinkResponsej\xd2\x04\n\rx-codeSamples\x12\xc0\x04\x32\xbd\x04\n\x86\x01*\x83\x01\n\x16\n\x05label\x12\r\x1a\x0bNode.js SDK\n\x14\n\x04lang\x12\x0c\x1a\njavascript\nS\n\x06source\x12I\x1aGconst link = await sc.organization.generatePortalLink(organization_id);\ny*w\n\x15\n\x05label\x12\x0c\x1a\nPython SDK\n\x10\n\x04lang\x12\x08\x1a\x06python\nL\n\x06source\x12\x42\x1a@link = sc.organization.generate_portal_link(\n  organization_id\n)\n{*y\n\x11\n\x05label\x12\x08\x1a\x06Go SDK\n\x0c\n\x04lang\x12\x04\x1a\x02go\nV\n\x06source\x12L\x1aJlink, err := sc.Organization.GeneratePortalLink(\n  ctx,\n  organizationId\n)\n\xb9\x01*\xb6\x01\n\x13\n\x05label\x12\n\x1a\x08Java SDK\n\x0e\n\x04lang\x12\x06\x1a\x04java\n\x8e\x01\n\x06source\x12\x83\x01\x1a\x80\x01Link portalLink = client\n  .organizations()\n  .generatePortalLink(organizationId, Arrays.asList(Feature.sso, Feature.dir_sync));\x82\xb5\x18\x02\x18T\x82\xd3\xe4\x93\x02)\x1a\'/api/v1/organizations/{id}/portal_links\x12\x99\x06\n\x10\x44\x65letePortalLink\x12\x32.scalekit.v1.organizations.DeletePortalLinkRequest\x1a\x16.google.protobuf.Empty\"\xb8\x05\x92\x41\xf0\x04\n\x0c\x41\x64min Portal\x12\x12\x44\x65lete portal link\x1a)Revokes and deletes an Admin portal link.J)\n\x03\x32\x30\x30\x12\"\n Portal link deleted successfullyj\xf5\x03\n\rx-codeSamples\x12\xe3\x03\x32\xe0\x03\n}*{\n\x16\n\x05label\x12\r\x1a\x0bNode.js SDK\n\x14\n\x04lang\x12\x0c\x1a\njavascript\nK\n\x06source\x12\x41\x1a?await sc.organization.deletePortalLink(organizationId, linkId);\n{*y\n\x15\n\x05label\x12\x0c\x1a\nPython SDK\n\x10\n\x04lang\x12\x08\x1a\x06python\nN\n\x06source\x12\x44\x1a\x42sc.organization.delete_portal_link(\n  organization_id,\n  link_id\n)\n}*{\n\x11\n\x05label\x12\x08\x1a\x06Go SDK\n\x0c\n\x04lang\x12\x04\x1a\x02go\nX\n\x06source\x12N\x1aLerr := sc.Organization.DeletePortalLink(\n  ctx,\n  organizationId,\n  linkId\n)\nc*a\n\x13\n\x05label\x12\n\x1a\x08Java SDK\n\x0e\n\x04lang\x12\x06\x1a\x04java\n:\n\x06source\x12\x30\x1a.// Hang in there. Coming soon! (Vroom! Vroom!)\x82\xb5\x18\x02\x18P\xfa\xd2\xe4\x93\x02\t\x12\x07PREVIEW\x82\xd3\xe4\x93\x02)*\'/api/v1/organizations/{id}/portal_links\x12\x9f\x02\n\x14\x44\x65letePortalLinkByID\x12\x36.scalekit.v1.organizations.DeletePortalLinkByIdRequest\x1a\x16.google.protobuf.Empty\"\xb6\x01\x92\x41\x65\n\x0c\x41\x64min Portal\x12\x18\x44\x65lete admin portal link\x1a)Revokes and deletes an Admin portal link.J\x10\n\x03\x32\x30\x30\x12\t\n\x07Success\x82\xb5\x18\x02\x18T\xfa\xd2\xe4\x93\x02\t\x12\x07PREVIEW\x82\xd3\xe4\x93\x02\x33*1/api/v1/organizations/{id}/portal_links/{link_id}\x12\xcc\x07\n\x0eGetPortalLinks\x12/.scalekit.v1.organizations.GetPortalLinkRequest\x1a\x31.scalekit.v1.organizations.GetPortalLinksResponse\"\xd5\x06\x92\x41\x8d\x06\n\x0c\x41\x64min Portal\x12\x0fGet portal link\x1a_Returns the Admin portal link if it exists. Use Generate Portal link to create and fetch a linkJG\n\x03\x32\x30\x30\x12@\n\x07Success\x12\x35\n3\x1a\x31.scalekit.v1.organizations.GetPortalLinksResponsej\xc1\x04\n\rx-codeSamples\x12\xaf\x04\x32\xac\x04\n|*z\n\x16\n\x05label\x12\r\x1a\x0bNode.js SDK\n\x14\n\x04lang\x12\x0c\x1a\njavascript\nJ\n\x06source\x12@\x1a>const links = sc.organization.getPortalLinks(organization_id);\nv*t\n\x15\n\x05label\x12\x0c\x1a\nPython SDK\n\x10\n\x04lang\x12\x08\x1a\x06python\nI\n\x06source\x12?\x1a=links = sc.organization.get_portal_links(\n  organization_id\n)\nx*v\n\x11\n\x05label\x12\x08\x1a\x06Go SDK\n\x0c\n\x04lang\x12\x04\x1a\x02go\nS\n\x06source\x12I\x1aGlinks, err := sc.Organization.GetPortalLinks(\n  ctx,\n  organizationId\n)\n\xb9\x01*\xb6\x01\n\x13\n\x05label\x12\n\x1a\x08Java SDK\n\x0e\n\x04lang\x12\x06\x1a\x04java\n\x8e\x01\n\x06source\x12\x83\x01\x1a\x80\x01Link portalLink = client\n  .organizations()\n  .generatePortalLink(organizationId, Arrays.asList(Feature.sso, Feature.dir_sync));\x82\xb5\x18\x02\x18P\xfa\xd2\xe4\x93\x02\t\x12\x07PREVIEW\x82\xd3\xe4\x93\x02)\x12\'/api/v1/organizations/{id}/portal_links\x12\xa5\x13\n\x1aUpdateOrganizationSettings\x12<.scalekit.v1.organizations.UpdateOrganizationSettingsRequest\x1a\x32.scalekit.v1.organizations.GetOrganizationResponse\"\x94\x12\x92\x41\xd5\x11\n\rOrganizations\x12\x1cToggle organization settings\x1a\xd3\x01Updates configuration settings for an organization. Supports modifying SSO configuration, directory synchronization settings, and session parameters. Requires organization ID and the specific settings to update.J\xe3\x01\n\x03\x32\x30\x30\x12\xdb\x01\n\xa0\x01Returns the complete organization object with updated settings applied. Contains all organization details including ID, display name, and the modified settings.\x12\x36\n4\x1a\x32.scalekit.v1.organizations.GetOrganizationResponseJp\n\x03\x34\x30\x30\x12i\ngInvalid request - occurs when the settings payload contains invalid values or unsupported configurationJM\n\x03\x34\x30\x34\x12\x46\nDOrganization not found - the specified organization ID doesn\'t existj\xa8\x0c\n\rx-codeSamples\x12\x96\x0c\x32\x93\x0c\n\xab\x02*\xa8\x02\n\x16\n\x05label\x12\r\x1a\x0bNode.js SDK\n\x14\n\x04lang\x12\x0c\x1a\njavascript\n\xf7\x01\n\x06source\x12\xec\x01\x1a\xe9\x01\x63onst settings = {\n  features: [\n    {\n      name: \'sso\',\n      enabled: true,\n    },\n    {\n      name: \'dir_sync\',\n      enabled: true,\n    },\n  ],\n};\n\nawait sc.organization.updateOrganizationSettings(\'<organization_id>\', settings);\n\xd5\x02*\xd2\x02\n\x15\n\x05label\x12\x0c\x1a\nPython SDK\n\x10\n\x04lang\x12\x08\x1a\x06python\n\xa6\x02\n\x06source\x12\x9b\x02\x1a\x98\x02settings = [\n        {\n            \"name\": \"sso\",\n            \"enabled\": true\n        },\n        {\n            \"name\": \"dir_sync\",\n            \"enabled\": true\n        }\n    ]\n\nsc.organization.update_organization_settings(\n  organization_id=\'<organization_id>\', settings=settings\n)\n\xbf\x02*\xbc\x02\n\x11\n\x05label\x12\x08\x1a\x06Go SDK\n\x0c\n\x04lang\x12\x04\x1a\x02go\n\x98\x02\n\x06source\x12\x8d\x02\x1a\x8a\x02settings := OrganizationSettings{\n\t\tFeatures: []Feature{\n\t\t\t{\n\t\t\t\tName:    \"sso\",\n\t\t\t\tEnabled: true,\n\t\t\t},\n\t\t\t{\n\t\t\t\tName:    \"dir_sync\",\n\t\t\t\tEnabled: true,\n\t\t\t},\n\t\t},\n\t}\n\norganization,err := sc.Organization().UpdateOrganizationSettings(ctx, organizationId, settings)\n\xc8\x04*\xc5\x04\n\x13\n\x05label\x12\n\x1a\x08Java SDK\n\x0e\n\x04lang\x12\x06\x1a\x04java\n\x9d\x04\n\x06source\x12\x92\x04\x1a\x8f\x04OrganizationSettingsFeature featureSSO = OrganizationSettingsFeature.newBuilder()\n                .setName(\"sso\")\n                .setEnabled(true)\n                .build();\n\nOrganizationSettingsFeature featureDirectorySync = OrganizationSettingsFeature.newBuilder()\n                .setName(\"dir_sync\")\n                .setEnabled(true)\n                .build();\n\nupdatedOrganization = scalekitClient.organizations()\n                .updateOrganizationSettings(organization.getId(), List.of(featureSSO, featureDirectorySync));\x82\xb5\x18\x02\x18T\x82\xd3\xe4\x93\x02/2#/api/v1/organizations/{id}/settings:\x08settings\x12\xda\x05\n!CreateOrganizationSessionSettings\x12\x43.scalekit.v1.organizations.CreateOrganizationSessionSettingsRequest\x1a\x44.scalekit.v1.organizations.CreateOrganizationSessionSettingsResponse\"\xa9\x04\x92\x41\xdd\x03\n\rOrganizations\x12$Create organization session settings\x1a\xf9\x01\x44\x65\x66ines session timeout policies for an organization, including absolute and idle timeout durations. This endpoint is used to configure session lifetimes and enhance security by automatically logging out users after a specified period of inactivity.J\xa9\x01\n\x03\x32\x30\x31\x12\xa1\x01\nUSession settings created successfully. Returns the newly configured session policies.\x12H\nF\x1a\x44.scalekit.v1.organizations.CreateOrganizationSessionSettingsResponse\x82\xb5\x18\x02\x18T\xfa\xd2\xe4\x93\x02\t\x12\x07PREVIEW\x82\xd3\xe4\x93\x02-\"+/api/v1/organizations/{id}/session-settings\x12\xb5\x04\n\x1eGetOrganizationSessionSettings\x12@.scalekit.v1.organizations.GetOrganizationSessionSettingsRequest\x1a\x41.scalekit.v1.organizations.GetOrganizationSessionSettingsResponse\"\x8d\x03\x92\x41\xc1\x02\n\rOrganizations\x12!Get organization session settings\x1a\x84\x01Retrieves the currently configured session timeout policies for a specific organization, including absolute and idle timeout values.J\x85\x01\n\x03\x32\x30\x30\x12~\n5Successfully retrieved organization session settings.\x12\x45\nC\x1a\x41.scalekit.v1.organizations.GetOrganizationSessionSettingsResponse\x82\xb5\x18\x02\x18T\xfa\xd2\xe4\x93\x02\t\x12\x07PREVIEW\x82\xd3\xe4\x93\x02-\x12+/api/v1/organizations/{id}/session-settings\x12\x8e\x05\n!UpdateOrganizationSessionSettings\x12\x43.scalekit.v1.organizations.UpdateOrganizationSessionSettingsRequest\x1a\x44.scalekit.v1.organizations.UpdateOrganizationSessionSettingsResponse\"\xdd\x03\x92\x41\xff\x02\n\rOrganizations\x12$Update organization session settings\x1a\xa3\x01Modifies the session timeout policies for an organization. Use this to adjust the absolute and idle session timeout durations to enforce different security levels.J\xa1\x01\n\x03\x32\x30\x30\x12\x99\x01\nMSession settings updated successfully. Returns the modified session policies.\x12H\nF\x1a\x44.scalekit.v1.organizations.UpdateOrganizationSessionSettingsResponse\x82\xb5\x18\x02\x18T\xfa\xd2\xe4\x93\x02\t\x12\x07PREVIEW\x82\xd3\xe4\x93\x02?2+/api/v1/organizations/{id}/session-settings:\x10session_settings\x12\xcc\x03\n!DeleteOrganizationSessionSettings\x12\x43.scalekit.v1.organizations.DeleteOrganizationSessionSettingsRequest\x1a\x16.google.protobuf.Empty\"\xc9\x02\x92\x41\xfd\x01\n\rOrganizations\x12$Delete organization session settings\x1a\x87\x01Resets an organization\'s session timeout policies to the default settings, removing any custom absolute or idle timeout configurations.J<\n\x03\x32\x30\x30\x12\x35\n3Organization session settings deleted successfully.\x82\xb5\x18\x02\x18T\xfa\xd2\xe4\x93\x02\t\x12\x07PREVIEW\x82\xd3\xe4\x93\x02-*+/api/v1/organizations/{id}/session-settings\x12\x92\x04\n\x1cUpdateUserManagementSettings\x12>.scalekit.v1.organizations.UpdateUserManagementSettingsRequest\x1a?.scalekit.v1.organizations.UpdateUserManagementSettingsResponse\"\xf0\x02\x92\x41\x8d\x02\n\rOrganizations\x12 Update organization user setting\x1a\x34Updates user management settings for an organizationJw\n\x03\x32\x30\x30\x12p\n)Returns the updated organization setting.\x12\x43\nA\x1a?.scalekit.v1.organizations.UpdateUserManagementSettingsResponseJ+\n\x03\x34\x30\x34\x12$\n\"Organization or setting not found.\x82\xb5\x18\x02\x18t\xfa\xd2\xe4\x93\x02\t\x12\x07PREVIEW\x82\xd3\xe4\x93\x02\x44\x32?/api/v1/organizations/{organization_id}/settings/usermanagement:\x01*\x12\xcc\x04\n$GetOrganizationUserManagementSetting\x12G.scalekit.v1.organizations.GetOrganizationUserManagementSettingsRequest\x1aH.scalekit.v1.organizations.GetOrganizationUserManagementSettingsResponse\"\x90\x03\x92\x41\xb0\x02\n\rOrganizations\x12(Get organization user management setting\x1a\x43Retrieves the user management settings for a specific organization.J\x82\x01\n\x03\x32\x30\x30\x12{\n+Returns the requested organization setting.\x12L\nJ\x1aH.scalekit.v1.organizations.GetOrganizationUserManagementSettingsResponseJ+\n\x03\x34\x30\x34\x12$\n\"Organization or setting not found.\x82\xb5\x18\x02\x18t\xfa\xd2\xe4\x93\x02\t\x12\x07PREVIEW\x82\xd3\xe4\x93\x02\x41\x12?/api/v1/organizations/{organization_id}/settings/usermanagement\x1aX\x92\x41U\n\rOrganizations\x12\x44{{import \"proto/scalekit/v1/organizations/organization_details.md\"}}B\xc4\x18Z7github.com/scalekit-inc/scalekit/pkg/grpc/organizations\x92\x41\x87\x18\x12\xad\x13\n\rScalekit APIs\x12\xd9\x0b# Introduction\n\nThe Scalekit API is a comprehensive RESTful API that enables you to manage organizations, users, authentication settings, and identity provider integrations. All requests must use HTTPS and require proper authentication.\n\n### Base URL\n\nAll API requests use the following base URLs:\n\n```\nhttps://{environment}.scalekit.dev (Development)\nhttps://{environment}.scalekit.com (Production)\nhttps://auth.example.com (Custom domain)\n```\n\nScalekit operates two separate environments: Development and Production. Resources cannot be moved between environments.\n\n# Authentication\n\nThe Scalekit API uses OAuth 2.0 Client Credentials for authentication.\n\nGetting an access token\n\n1. Get your credentials from the [Scalekit Dashboard](https://app.scalekit.com): `SCALEKIT_ENVIRONMENT_URL`, `SCALEKIT_CLIENT_ID`, `SCALEKIT_CLIENT_SECRET`\n\n2. Request an access token:\n\n```shell\ncurl https://{SCALEKIT_ENVIRONMENT_URL}/oauth/token \\\n  -X POST \\\n  -H \'Content-Type: application/x-www-form-urlencoded\' \\\n  -d \'client_id={client_id}\' \\\n  -d \'client_secret={client_secret}\' \\\n  -d \'grant_type=client_credentials\'\n```\n\nUse the access token in API requests:\n\n```shell\ncurl https://{SCALEKIT_ENVIRONMENT_URL}/api/v1/organizations \\\n  -H \'Content-Type: application/json\' \\\n  -H \'Authorization: Bearer {access_token}\'\n```\n\nThe response includes an access token:\n\n```json\n{\n\t\"access_token\": \"eyJhbGciOiJSUzI1NiIsImInR5cCI6IkpXVCJ9...\",\n\t\"token_type\": \"Bearer\",\n\t\"expires_in\": 86399,\n\t\"scope\": \"openid\"\n}\n```\n\":\n\x0cScalekit Inc\x12\x14https://scalekit.com\x1a\x14support@scalekit.com*8\n\nApache 2.0\x12*http://www.apache.org/licenses/LICENSE-2.02\x05\x31.0.0:\xc2\x06\n\x19x-scalar-sdk-installation\x12\xa4\x06\x32\xa1\x06\n\x7f*}\n?\n\x0b\x64\x65scription\x12\x30\x1a.Install the Scalekit SDK for Node.js from npm:\n\x0e\n\x04lang\x12\x06\x1a\x04node\n*\n\x06source\x12 \x1a\x1enpm install @scalekit-sdk/node\n\x83\x01*\x80\x01\n?\n\x0b\x64\x65scription\x12\x30\x1a.Install the Scalekit SDK for Python using pip:\n\x10\n\x04lang\x12\x08\x1a\x06python\n+\n\x06source\x12!\x1a\x1fpip install scalekit-sdk-python\n\x83\x01*\x80\x01\n1\n\x0b\x64\x65scription\x12\"\x1a Install the Scalekit SDK for Go:\n\x0c\n\x04lang\x12\x04\x1a\x02Go\n=\n\x06source\x12\x33\x1a\x31go get -u github.com/scalekit-inc/scalekit-sdk-go\n\x91\x03*\x8e\x03\n+\n\x0b\x64\x65scription\x12\x1c\x1a\x1a\x41\x64\x64ing Java SDK dependency\n\x0e\n\x04lang\x12\x06\x1a\x04Java\n\xce\x02\n\x06source\x12\xc3\x02\x1a\xc0\x02/* Gradle users - add the following to your dependencies in build file */\nimplementation \"com.scalekit:scalekit-sdk-java:2.0.1\"\n\n<!-- Maven users - add the following to your `pom.xml` -->\n<dependency>\n  <groupId>com.scalekit</groupId>\n  <artifactId>scalekit-sdk-java</artifactId>\n  <version>2.0.1</version>\n</dependency>\x1a\x19$SCALEKIT_ENVIRONMENT_URL*\x01\x02\x32\x10\x61pplication/json:\x10\x61pplication/jsonj\x0f\n\rOrganizationsj\xd4\x03\n\x0bPermissions\x12\xc4\x03Permission management for defining and controlling access to system resources. Create, retrieve, update, and delete granular permissions that represent specific actions users can perform. Permissions are the building blocks of role-based access control (RBAC) and can be assigned to roles to grant users the ability to perform specific operations. Use this service to define custom permissions for your application\'s unique access control requirements.r+\n\rScalekit Docs\x12\x1ahttps://docs.scalekit.com/b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'scalekit.v1.organizations.organizations_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z7github.com/scalekit-inc/scalekit/pkg/grpc/organizations\222A\207\030\022\255\023\n\rScalekit APIs\022\331\013# Introduction\n\nThe Scalekit API is a comprehensive RESTful API that enables you to manage organizations, users, authentication settings, and identity provider integrations. All requests must use HTTPS and require proper authentication.\n\n### Base URL\n\nAll API requests use the following base URLs:\n\n```\nhttps://{environment}.scalekit.dev (Development)\nhttps://{environment}.scalekit.com (Production)\nhttps://auth.example.com (Custom domain)\n```\n\nScalekit operates two separate environments: Development and Production. Resources cannot be moved between environments.\n\n# Authentication\n\nThe Scalekit API uses OAuth 2.0 Client Credentials for authentication.\n\nGetting an access token\n\n1. Get your credentials from the [Scalekit Dashboard](https://app.scalekit.com): `SCALEKIT_ENVIRONMENT_URL`, `SCALEKIT_CLIENT_ID`, `SCALEKIT_CLIENT_SECRET`\n\n2. Request an access token:\n\n```shell\ncurl https://{SCALEKIT_ENVIRONMENT_URL}/oauth/token \\\n  -X POST \\\n  -H \'Content-Type: application/x-www-form-urlencoded\' \\\n  -d \'client_id={client_id}\' \\\n  -d \'client_secret={client_secret}\' \\\n  -d \'grant_type=client_credentials\'\n```\n\nUse the access token in API requests:\n\n```shell\ncurl https://{SCALEKIT_ENVIRONMENT_URL}/api/v1/organizations \\\n  -H \'Content-Type: application/json\' \\\n  -H \'Authorization: Bearer {access_token}\'\n```\n\nThe response includes an access token:\n\n```json\n{\n\t\"access_token\": \"eyJhbGciOiJSUzI1NiIsImInR5cCI6IkpXVCJ9...\",\n\t\"token_type\": \"Bearer\",\n\t\"expires_in\": 86399,\n\t\"scope\": \"openid\"\n}\n```\n\":\n\014Scalekit Inc\022\024https://scalekit.com\032\024support@scalekit.com*8\n\nApache 2.0\022*http://www.apache.org/licenses/LICENSE-2.02\0051.0.0:\302\006\n\031x-scalar-sdk-installation\022\244\0062\241\006\n\177*}\n?\n\013description\0220\032.Install the Scalekit SDK for Node.js from npm:\n\016\n\004lang\022\006\032\004node\n*\n\006source\022 \032\036npm install @scalekit-sdk/node\n\203\001*\200\001\n?\n\013description\0220\032.Install the Scalekit SDK for Python using pip:\n\020\n\004lang\022\010\032\006python\n+\n\006source\022!\032\037pip install scalekit-sdk-python\n\203\001*\200\001\n1\n\013description\022\"\032 Install the Scalekit SDK for Go:\n\014\n\004lang\022\004\032\002Go\n=\n\006source\0223\0321go get -u github.com/scalekit-inc/scalekit-sdk-go\n\221\003*\216\003\n+\n\013description\022\034\032\032Adding Java SDK dependency\n\016\n\004lang\022\006\032\004Java\n\316\002\n\006source\022\303\002\032\300\002/* Gradle users - add the following to your dependencies in build file */\nimplementation \"com.scalekit:scalekit-sdk-java:2.0.1\"\n\n<!-- Maven users - add the following to your `pom.xml` -->\n<dependency>\n  <groupId>com.scalekit</groupId>\n  <artifactId>scalekit-sdk-java</artifactId>\n  <version>2.0.1</version>\n</dependency>\032\031$SCALEKIT_ENVIRONMENT_URL*\001\0022\020application/json:\020application/jsonj\017\n\rOrganizationsj\324\003\n\013Permissions\022\304\003Permission management for defining and controlling access to system resources. Create, retrieve, update, and delete granular permissions that represent specific actions users can perform. Permissions are the building blocks of role-based access control (RBAC) and can be assigned to roles to grant users the ability to perform specific operations. Use this service to define custom permissions for your application\'s unique access control requirements.r+\n\rScalekit Docs\022\032https://docs.scalekit.com/'
  _globals['_FEATURE']._loaded_options = None
  _globals['_FEATURE']._serialized_options = b'\020\001'
  _globals['_FEATURE'].values_by_name["UNSPECIFIED"]._loaded_options = None
  _globals['_FEATURE'].values_by_name["UNSPECIFIED"]._serialized_options = b'\010\001'
  _globals['_CREATEORGANIZATIONREQUEST'].fields_by_name['organization']._loaded_options = None
  _globals['_CREATEORGANIZATIONREQUEST'].fields_by_name['organization']._serialized_options = b'\222A523Required parameters for creating a new organization\272H\003\310\001\001'
  _globals['_CREATEORGANIZATIONRESPONSE'].fields_by_name['organization']._loaded_options = None
  _globals['_CREATEORGANIZATIONRESPONSE'].fields_by_name['organization']._serialized_options = b'\222AJ2HThe newly created organization containing its ID, settings, and metadata'
  _globals['_CREATEORGANIZATION_METADATAENTRY']._loaded_options = None
  _globals['_CREATEORGANIZATION_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_CREATEORGANIZATION'].fields_by_name['display_name']._loaded_options = None
  _globals['_CREATEORGANIZATION'].fields_by_name['display_name']._serialized_options = b'\222AQ2?Name of the organization. Must be between 1 and 200 characters.J\016\"Megasoft Inc\"\340A\002\272H\007r\005\020\001\030\310\001'
  _globals['_CREATEORGANIZATION'].fields_by_name['region_code']._loaded_options = None
  _globals['_CREATEORGANIZATION'].fields_by_name['region_code']._serialized_options = b'\222AL2DGeographic region code for the organization. Currently limited to USJ\004\"US\"\372\322\344\223\002\t\022\007PREVIEW'
  _globals['_CREATEORGANIZATION'].fields_by_name['external_id']._loaded_options = None
  _globals['_CREATEORGANIZATION'].fields_by_name['external_id']._serialized_options = b'\222Au2cYour application\'s unique identifier for this organization, used to link Scalekit with your system.J\016\"my_unique_id\"'
  _globals['_CREATEORGANIZATION'].fields_by_name['metadata']._loaded_options = None
  _globals['_CREATEORGANIZATION'].fields_by_name['metadata']._serialized_options = b'\272H\026\232\001\023\020\n\"\006r\004\020\003\030\031*\007r\005\020\001\030\200\002'
  _globals['_ORGANIZATION_METADATAENTRY']._loaded_options = None
  _globals['_ORGANIZATION_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_ORGANIZATION'].fields_by_name['id']._loaded_options = None
  _globals['_ORGANIZATION'].fields_by_name['id']._serialized_options = b'\222Ah2MUnique scalekit-generated identifier that uniquely references an organizationJ\027\"org_59615193906282635\"'
  _globals['_ORGANIZATION'].fields_by_name['create_time']._loaded_options = None
  _globals['_ORGANIZATION'].fields_by_name['create_time']._serialized_options = b'\222AI2+Timestamp when the organization was createdJ\032\"2025-02-15T06:23:44.560Z\"\340A\002'
  _globals['_ORGANIZATION'].fields_by_name['update_time']._loaded_options = None
  _globals['_ORGANIZATION'].fields_by_name['update_time']._serialized_options = b'\222AN20Timestamp when the organization was last updatedJ\032\"2025-02-15T06:23:44.560Z\"'
  _globals['_ORGANIZATION'].fields_by_name['display_name']._loaded_options = None
  _globals['_ORGANIZATION'].fields_by_name['display_name']._serialized_options = b'\222AL2>Name of the organization. Must be between 1 and 200 charactersJ\n\"Megasoft\"\272H\007r\005\020\001\030\310\001'
  _globals['_ORGANIZATION'].fields_by_name['region_code']._loaded_options = None
  _globals['_ORGANIZATION'].fields_by_name['region_code']._serialized_options = b'\222AM2EGeographic region code for the organization. Currently limited to US.J\004\"US\"'
  _globals['_ORGANIZATION'].fields_by_name['external_id']._loaded_options = None
  _globals['_ORGANIZATION'].fields_by_name['external_id']._serialized_options = b'\222Au2cYour application\'s unique identifier for this organization, used to link Scalekit with your system.J\016\"my_unique_id\"'
  _globals['_ORGANIZATION'].fields_by_name['metadata']._loaded_options = None
  _globals['_ORGANIZATION'].fields_by_name['metadata']._serialized_options = b'\272H\026\232\001\023\020\n\"\006r\004\020\003\030\031*\007r\005\020\001\030\200\002'
  _globals['_UPDATEORGANIZATIONREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_UPDATEORGANIZATIONREQUEST'].fields_by_name['id']._serialized_options = b'\222AL23Unique identifier of the organization to be updatedJ\025\"org_121312434123312\"\272H\006r\004\020\001\030 '
  _globals['_UPDATEORGANIZATIONREQUEST'].fields_by_name['external_id']._loaded_options = None
  _globals['_UPDATEORGANIZATIONREQUEST'].fields_by_name['external_id']._serialized_options = b'\222AI2-External ID of the organization to be updatedJ\030\"tenant_123123123123123\"\272H\004r\002\020\001\372\322\344\223\002\t\022\007PREVIEW'
  _globals['_UPDATEORGANIZATIONREQUEST'].fields_by_name['organization']._loaded_options = None
  _globals['_UPDATEORGANIZATIONREQUEST'].fields_by_name['organization']._serialized_options = b'\222A\'2%Organization Parameters to be updated\272H\003\310\001\001'
  _globals['_UPDATEORGANIZATION_METADATAENTRY']._loaded_options = None
  _globals['_UPDATEORGANIZATION_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_UPDATEORGANIZATION'].fields_by_name['display_name']._loaded_options = None
  _globals['_UPDATEORGANIZATION'].fields_by_name['display_name']._serialized_options = b'\222Ai2SName of the organization to display in the UI. Must be between 1 and 200 charactersJ\022\"Acme Corporation\"\272H\007r\005\020\001\030\310\001'
  _globals['_UPDATEORGANIZATION'].fields_by_name['external_id']._loaded_options = None
  _globals['_UPDATEORGANIZATION'].fields_by_name['external_id']._serialized_options = b'\222At2bYour application\'s unique identifier for this organization, used to link Scalekit with your systemJ\016\"tenant_12345\"'
  _globals['_UPDATEORGANIZATION'].fields_by_name['metadata']._loaded_options = None
  _globals['_UPDATEORGANIZATION'].fields_by_name['metadata']._serialized_options = b'\222A\256\0012\217\001Custom key-value pairs to store with the organization. Keys must be 3-25 characters, values must be 1-256 characters. Maximum 10 pairs allowed.J\032{\"industry\": \"technology\"}\272H\026\232\001\023\020\n\"\006r\004\020\003\030\031*\007r\005\020\001\030\200\002'
  _globals['_UPDATEORGANIZATIONRESPONSE'].fields_by_name['organization']._loaded_options = None
  _globals['_UPDATEORGANIZATIONRESPONSE'].fields_by_name['organization']._serialized_options = b'\222A\0362\034Updated organization details'
  _globals['_GETORGANIZATIONREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_GETORGANIZATIONREQUEST'].fields_by_name['id']._serialized_options = b'\222Af2MUnique scalekit-generated identifier that uniquely references an organizationJ\025\"org_121312434123312\"\272H\006r\004\020\001\030 '
  _globals['_GETORGANIZATIONREQUEST'].fields_by_name['external_id']._loaded_options = None
  _globals['_GETORGANIZATIONREQUEST'].fields_by_name['external_id']._serialized_options = b'\222A~2bUnique identifier that links an Organization Object to your app\'s tenant, stored as an External IDJ\030\"tenant_123123123123123\"\272H\004r\002\020\001\372\322\344\223\002\t\022\007PREVIEW'
  _globals['_GETORGANIZATIONRESPONSE'].fields_by_name['organization']._loaded_options = None
  _globals['_GETORGANIZATIONRESPONSE'].fields_by_name['organization']._serialized_options = b'\222A 2\036The newly created organization'
  _globals['_LISTORGANIZATIONSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTORGANIZATIONSREQUEST'].fields_by_name['page_size']._serialized_options = b'\222AT2NMaximum number of organizations to return per page. Must be between 10 and 100J\00230'
  _globals['_LISTORGANIZATIONSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTORGANIZATIONSREQUEST'].fields_by_name['page_token']._serialized_options = b'\222Am2[Pagination token from the previous response. Use to retrieve the next page of organizationsJ\016\"<page_token>\"'
  _globals['_LISTORGANIZATIONSREQUEST'].fields_by_name['external_id']._loaded_options = None
  _globals['_LISTORGANIZATIONSREQUEST'].fields_by_name['external_id']._serialized_options = b'\222A~2bYour application\'s unique identifier for this organization, used to link Scalekit with your systemJ\030\"<your_app_assigned_id>\"'
  _globals['_LISTORGANIZATIONSREQUEST']._loaded_options = None
  _globals['_LISTORGANIZATIONSREQUEST']._serialized_options = b'\222A\374\001\n\253\001*\022List Organizations2\224\001Retrieves a paginated list of all organizations within the environment. Use the `page_token` from the response to access subsequent pages of results*L\n\022List Organizations\0226https://docs.scalekit.com/reference/list-organizations'
  _globals['_LISTORGANIZATIONSRESPONSE'].fields_by_name['next_page_token']._loaded_options = None
  _globals['_LISTORGANIZATIONSRESPONSE'].fields_by_name['next_page_token']._serialized_options = b'\222Al2UPagination token for the next page of results. Use this token to fetch the next page.J\023\"<next_page_token>\"'
  _globals['_LISTORGANIZATIONSRESPONSE'].fields_by_name['total_size']._loaded_options = None
  _globals['_LISTORGANIZATIONSRESPONSE'].fields_by_name['total_size']._serialized_options = b'\222A721Total number of organizations in the environment.J\00230'
  _globals['_LISTORGANIZATIONSRESPONSE'].fields_by_name['organizations']._loaded_options = None
  _globals['_LISTORGANIZATIONSRESPONSE'].fields_by_name['organizations']._serialized_options = b'\222A\0362\034List of organization objects'
  _globals['_LISTORGANIZATIONSRESPONSE'].fields_by_name['prev_page_token']._loaded_options = None
  _globals['_LISTORGANIZATIONSRESPONSE'].fields_by_name['prev_page_token']._serialized_options = b'\222At2]Pagination token for the previous page of results. Use this token to fetch the previous page.J\023\"<prev_page_token>\"'
  _globals['_SEARCHORGANIZATIONSREQUEST'].fields_by_name['query']._loaded_options = None
  _globals['_SEARCHORGANIZATIONSREQUEST'].fields_by_name['query']._serialized_options = b'\222A\1772wSearch term to match against organization names, IDs, or external IDs. Must be at least 3 characters. Case insensitive.J\004acme\272H\tr\004\020\003\030d\310\001\001'
  _globals['_SEARCHORGANIZATIONSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_SEARCHORGANIZATIONSREQUEST'].fields_by_name['page_size']._serialized_options = b'\222AY2SMaximum number of organizations to return per page. Value must be between 1 and 30.J\00230\272H\004*\002\030\036'
  _globals['_SEARCHORGANIZATIONSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_SEARCHORGANIZATIONSREQUEST'].fields_by_name['page_token']._serialized_options = b'\222A\201\0012aToken from a previous response for pagination. Provide this to retrieve the next page of results.J\034eyJwYWdlIjoyLCJsaW1pdCI6MzB9'
  _globals['_SEARCHORGANIZATIONSREQUEST']._loaded_options = None
  _globals['_SEARCHORGANIZATIONSREQUEST']._serialized_options = b'\222A\261\001\n\210\001*\024Search Organizations2pSearch for organizations in your environment using a text query that matches against names, IDs, or external IDs2$query=acme&page_size=30&page_token=1'
  _globals['_DELETEORGANIZATIONREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_DELETEORGANIZATIONREQUEST'].fields_by_name['id']._serialized_options = b'\222A`2MUnique scalekit-generated identifier that uniquely references an organizationJ\017\"org_123456789\"\272H\006r\004\020\001\030 '
  _globals['_DELETEORGANIZATIONREQUEST'].fields_by_name['external_id']._loaded_options = None
  _globals['_DELETEORGANIZATIONREQUEST'].fields_by_name['external_id']._serialized_options = b'\222AE2)External ID of the organization to deleteJ\030\"tenant_123123123123123\"\272H\004r\002\020\001\372\322\344\223\002\t\022\007PREVIEW'
  _globals['_GENERATEPORTALLINKREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_GENERATEPORTALLINKREQUEST'].fields_by_name['id']._serialized_options = b'\222A)2\017Organization IDJ\026\"org_1231234233424344\"\272H\017r\n\020\001\030 :\004org_\310\001\001'
  _globals['_GENERATEPORTALLINKREQUEST'].fields_by_name['sso']._loaded_options = None
  _globals['_GENERATEPORTALLINKREQUEST'].fields_by_name['sso']._serialized_options = b'\030\001\372\322\344\223\002\t\022\007PREVIEW'
  _globals['_GENERATEPORTALLINKREQUEST'].fields_by_name['directory_sync']._loaded_options = None
  _globals['_GENERATEPORTALLINKREQUEST'].fields_by_name['directory_sync']._serialized_options = b'\030\001\372\322\344\223\002\t\022\007PREVIEW'
  _globals['_GENERATEPORTALLINKREQUEST'].fields_by_name['features']._loaded_options = None
  _globals['_GENERATEPORTALLINKREQUEST'].fields_by_name['features']._serialized_options = b'\222A\230\0022\225\002Features to enable in the admin portal link. To enable features, append them as URL parameters:\n\n- Single Sign-On: ?features=sso\n- Directory Sync: ?features=dir_sync\n- Both features: ?features=sso&features=dir_sync\n\nExample URL: https://scalekit.com/portal/lnk_123?features=sso'
  _globals['_GETPORTALLINKREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_GETPORTALLINKREQUEST'].fields_by_name['id']._serialized_options = b'\222A)2\017Organization IDJ\026\"org_1231234233424344\"\272H\017r\n\020\001\030 :\004org_\310\001\001'
  _globals['_DELETEPORTALLINKREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_DELETEPORTALLINKREQUEST'].fields_by_name['id']._serialized_options = b'\222A)2\017Organization IDJ\026\"org_1231234233424344\"\272H\017r\n\020\001\030 :\004org_\310\001\001'
  _globals['_DELETEPORTALLINKBYIDREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_DELETEPORTALLINKBYIDREQUEST'].fields_by_name['id']._serialized_options = b'\222A)2\017Organization IDJ\026\"org_1231234233424344\"\272H\017r\n\020\001\030 :\004org_\310\001\001'
  _globals['_DELETEPORTALLINKBYIDREQUEST'].fields_by_name['link_id']._loaded_options = None
  _globals['_DELETEPORTALLINKBYIDREQUEST'].fields_by_name['link_id']._serialized_options = b'\222A!2\007Link IDJ\026\"lnk_1231234233424344\"\272H\017r\n\020\001\030 :\004lnk_\310\001\001'
  _globals['_LINK'].fields_by_name['id']._loaded_options = None
  _globals['_LINK'].fields_by_name['id']._serialized_options = b'\222A72\036Unique Identifier for the linkJ\025\"lnk_123123123123123\"'
  _globals['_LINK'].fields_by_name['location']._loaded_options = None
  _globals['_LINK'].fields_by_name['location']._serialized_options = b'\222A\245\0012pLocation of the link. This is the URL that can be used to access the Admin portal. The link is valid for 1 week.J1\"https://scalekit.com/portal/lnk_123123123123123\"'
  _globals['_LINK'].fields_by_name['expire_time']._loaded_options = None
  _globals['_LINK'].fields_by_name['expire_time']._serialized_options = b'\222AT26Expiry time of the link. The link is valid for 1 week.J\032\"2024-02-06T14:48:00.000Z\"'
  _globals['_GENERATEPORTALLINKRESPONSE'].fields_by_name['link']._loaded_options = None
  _globals['_GENERATEPORTALLINKRESPONSE'].fields_by_name['link']._serialized_options = b'\222A\275\0012\272\001Contains the generated admin portal link details. The link URL can be shared with organization administrators to set up: Single Sign-On (SSO) authentication and directory synchronization'
  _globals['_GETPORTALLINKSRESPONSE'].fields_by_name['links']._loaded_options = None
  _globals['_GETPORTALLINKSRESPONSE'].fields_by_name['links']._serialized_options = b'\222A\0242\022Admin Portal Links'
  _globals['_UPDATEORGANIZATIONSETTINGSREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_UPDATEORGANIZATIONSETTINGSREQUEST'].fields_by_name['id']._serialized_options = b'\222Aq2WUnique identifier of the organization to update settings. Must begin with \'org_\' prefixJ\026\"org_1231234233424344\"\272H\017r\n\020\001\030 :\004org_\310\001\001'
  _globals['_UPDATEORGANIZATIONSETTINGSREQUEST'].fields_by_name['settings']._loaded_options = None
  _globals['_UPDATEORGANIZATIONSETTINGSREQUEST'].fields_by_name['settings']._serialized_options = b'\222A\370\0012\225\001Settings configuration to apply to the organization. Contains feature toggles for SSO, directory synchronization, and other organization capabilitiesJ^{\"features\": [{\"name\": \"sso\", \"enabled\": true}, {\"name\": \"directory_sync\", \"enabled\": false}]}\272H\003\310\001\001'
  _globals['_UPDATEORGANIZATIONSESSIONSETTINGSREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_UPDATEORGANIZATIONSESSIONSETTINGSREQUEST'].fields_by_name['id']._serialized_options = b'\222Ac2HUnique identifier for the organization, beginning with an \'org_\' prefix.J\027\"org_59615193906282635\"\272H\013r\t\020\001\030 :\003org'
  _globals['_UPDATEORGANIZATIONSESSIONSETTINGSREQUEST'].fields_by_name['environment_id']._loaded_options = None
  _globals['_UPDATEORGANIZATIONSESSIONSETTINGSREQUEST'].fields_by_name['environment_id']._serialized_options = b'\222A\270\0012\234\001Unique identifier for the environment where the organization resides, prefixed with \'env_\'. This specifies the environment context for the session settings.J\027\"env_59615193906282635\"\272H\013r\t\020\001\030 :\003env'
  _globals['_UPDATEORGANIZATIONSESSIONSETTINGSREQUEST'].fields_by_name['session_settings']._loaded_options = None
  _globals['_UPDATEORGANIZATIONSESSIONSETTINGSREQUEST'].fields_by_name['session_settings']._serialized_options = b'\222AY2WThe session settings to be applied, including absolute and idle timeout configurations.\272H\003\310\001\001'
  _globals['_UPDATEORGANIZATIONSESSIONSETTINGSRESPONSE'].fields_by_name['environment_id']._loaded_options = None
  _globals['_UPDATEORGANIZATIONSESSIONSETTINGSRESPONSE'].fields_by_name['environment_id']._serialized_options = b'\222Ae2JThe environment ID where the organization\'s session settings were updated.J\027\"env_59615193906282635\"'
  _globals['_UPDATEORGANIZATIONSESSIONSETTINGSRESPONSE'].fields_by_name['organization_id']._loaded_options = None
  _globals['_UPDATEORGANIZATIONSESSIONSETTINGSRESPONSE'].fields_by_name['organization_id']._serialized_options = b'\222Ai2NThe unique identifier of the organization whose session settings were updated.J\027\"org_59615193906282635\"'
  _globals['_UPDATEORGANIZATIONSESSIONSETTINGSRESPONSE'].fields_by_name['session_settings']._loaded_options = None
  _globals['_UPDATEORGANIZATIONSESSIONSETTINGSRESPONSE'].fields_by_name['session_settings']._serialized_options = b'\222AD2BThe updated session settings, reflecting the new timeout policies.'
  _globals['_ORGANIZATIONUSERMANAGEMENTSETTINGS'].fields_by_name['jit_provisioning_with_sso_enabled']._loaded_options = None
  _globals['_ORGANIZATIONUSERMANAGEMENTSETTINGS'].fields_by_name['jit_provisioning_with_sso_enabled']._serialized_options = b'\222A\1772wEnables or disables user management features for the organization. When true, users can be added, removed, and managed.J\004true'
  _globals['_ORGANIZATIONUSERMANAGEMENTSETTINGS'].fields_by_name['sync_user_profile_on_signin']._loaded_options = None
  _globals['_ORGANIZATIONUSERMANAGEMENTSETTINGS'].fields_by_name['sync_user_profile_on_signin']._serialized_options = b'\222A\266\0012\255\001Enables or disables synchronization of user profiles upon sign-in. When true, user profiles are automatically updated with the latest information from the identity provider.J\004true'
  _globals['_ORGANIZATIONUSERMANAGEMENTSETTINGS'].fields_by_name['deprecated_placeholder']._loaded_options = None
  _globals['_ORGANIZATIONUSERMANAGEMENTSETTINGS'].fields_by_name['deprecated_placeholder']._serialized_options = b'\030\001\222A-2+Deprecated placeholder (no functional use).\372\322\344\223\002\t\022\007PREVIEW'
  _globals['_ORGANIZATIONSESSIONSETTINGS'].fields_by_name['absolute_session_timeout']._loaded_options = None
  _globals['_ORGANIZATIONSESSIONSETTINGS'].fields_by_name['absolute_session_timeout']._serialized_options = b'\222A\242\0012\230\001The maximum duration in seconds that a session can remain active, regardless of activity. After this time, the user will be required to re-authenticate.J\00586400'
  _globals['_ORGANIZATIONSESSIONSETTINGS'].fields_by_name['session_management_enabled']._loaded_options = None
  _globals['_ORGANIZATIONSESSIONSETTINGS'].fields_by_name['session_management_enabled']._serialized_options = b'\222A\1772wEnables or disables session management features for the organization. When true, session timeout policies are enforced.J\004true'
  _globals['_ORGANIZATIONSESSIONSETTINGS'].fields_by_name['idle_session_timeout']._loaded_options = None
  _globals['_ORGANIZATIONSESSIONSETTINGS'].fields_by_name['idle_session_timeout']._serialized_options = b'\222A\200\0012xThe duration in seconds that a session can remain idle before it is automatically terminated. Activity resets the timer.J\0041800'
  _globals['_ORGANIZATIONSESSIONSETTINGS'].fields_by_name['idle_session_enabled']._loaded_options = None
  _globals['_ORGANIZATIONSESSIONSETTINGS'].fields_by_name['idle_session_enabled']._serialized_options = b'\222A\202\0012zEnables or disables idle session timeout. If true, inactive sessions will be terminated after the specified idle duration.J\004true'
  _globals['_GETORGANIZATIONSESSIONSETTINGSREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_GETORGANIZATIONSESSIONSETTINGSREQUEST'].fields_by_name['id']._serialized_options = b'\222Ap2UThe unique identifier of the organization whose session settings are being requested.J\027\"org_59615193906282635\"\272H\013r\t\020\001\030 :\003org'
  _globals['_GETORGANIZATIONSESSIONSETTINGSREQUEST'].fields_by_name['environment_id']._loaded_options = None
  _globals['_GETORGANIZATIONSESSIONSETTINGSREQUEST'].fields_by_name['environment_id']._serialized_options = b'\222A\211\0012nThe environment ID to scope the request. This ensures the settings are retrieved from the correct environment.J\027\"env_59615193906282635\"\272H\013r\t\020\001\030 :\003env'
  _globals['_CREATEORGANIZATIONSESSIONSETTINGSREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_CREATEORGANIZATIONSESSIONSETTINGSREQUEST'].fields_by_name['id']._serialized_options = b'\222Aj2OThe unique identifier of the organization for which to create session settings.J\027\"org_59615193906282635\"\272H\013r\t\020\001\030 :\003org'
  _globals['_CREATEORGANIZATIONSESSIONSETTINGSREQUEST'].fields_by_name['environment_id']._loaded_options = None
  _globals['_CREATEORGANIZATIONSESSIONSETTINGSREQUEST'].fields_by_name['environment_id']._serialized_options = b'\222A\224\0012yThe environment ID where the organization exists. This scopes the creation of session settings to a specific environment.J\027\"env_59615193906282635\"\272H\013r\t\020\001\030 :\003env'
  _globals['_CREATEORGANIZATIONSESSIONSETTINGSRESPONSE'].fields_by_name['environment_id']._loaded_options = None
  _globals['_CREATEORGANIZATIONSESSIONSETTINGSRESPONSE'].fields_by_name['environment_id']._serialized_options = b'\222AV2;The environment ID where the session settings were created.J\027\"env_59615193906282635\"'
  _globals['_CREATEORGANIZATIONSESSIONSETTINGSRESPONSE'].fields_by_name['organization_id']._loaded_options = None
  _globals['_CREATEORGANIZATIONSESSIONSETTINGSRESPONSE'].fields_by_name['organization_id']._serialized_options = b'\222Am2RThe unique identifier of the organization for which session settings were created.J\027\"org_59615193906282635\"'
  _globals['_CREATEORGANIZATIONSESSIONSETTINGSRESPONSE'].fields_by_name['session_settings']._loaded_options = None
  _globals['_CREATEORGANIZATIONSESSIONSETTINGSRESPONSE'].fields_by_name['session_settings']._serialized_options = b'\222AA2?The newly created session settings, including timeout policies.'
  _globals['_GETORGANIZATIONSESSIONSETTINGSRESPONSE'].fields_by_name['environment_id']._loaded_options = None
  _globals['_GETORGANIZATIONSESSIONSETTINGSRESPONSE'].fields_by_name['environment_id']._serialized_options = b'\222A]2BThe environment ID from which the session settings were retrieved.J\027\"env_59615193906282635\"'
  _globals['_GETORGANIZATIONSESSIONSETTINGSRESPONSE'].fields_by_name['organization_id']._loaded_options = None
  _globals['_GETORGANIZATIONSESSIONSETTINGSRESPONSE'].fields_by_name['organization_id']._serialized_options = b'\222Ai2NThe unique identifier of the organization whose session settings are returned.J\027\"org_59615193906282635\"'
  _globals['_GETORGANIZATIONSESSIONSETTINGSRESPONSE'].fields_by_name['session_settings']._loaded_options = None
  _globals['_GETORGANIZATIONSESSIONSETTINGSRESPONSE'].fields_by_name['session_settings']._serialized_options = b'\222A>2<The retrieved session timeout policies for the organization.'
  _globals['_DELETEORGANIZATIONSESSIONSETTINGSREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_DELETEORGANIZATIONSESSIONSETTINGSREQUEST'].fields_by_name['id']._serialized_options = b'\222An2SThe unique identifier of the organization whose session settings should be deleted.J\027\"org_59615193906282635\"\272H\013r\t\020\001\030 :\003org'
  _globals['_DELETEORGANIZATIONSESSIONSETTINGSREQUEST'].fields_by_name['environment_id']._loaded_options = None
  _globals['_DELETEORGANIZATIONSESSIONSETTINGSREQUEST'].fields_by_name['environment_id']._serialized_options = b'\222A\225\0012zThe environment ID to scope the deletion. This ensures that the session settings are removed from the correct environment.J\027\"env_59615193906282635\"\272H\013r\t\020\001\030 :\003env'
  _globals['_ORGANIZATIONSETTINGS'].fields_by_name['features']._loaded_options = None
  _globals['_ORGANIZATIONSETTINGS'].fields_by_name['features']._serialized_options = b'\222A\313\0012wList of feature toggles that control organization capabilities such as SSO authentication and directory synchronizationJP[{\"name\": \"sso\", \"enabled\": true}, {\"name\": \"directory_sync\", \"enabled\": false}]'
  _globals['_ORGANIZATIONSETTINGS']._loaded_options = None
  _globals['_ORGANIZATIONSETTINGS']._serialized_options = b'\222A\312\001\nh*\025Organization Settings2OConfiguration options that control organization-level features and capabilities2^{\"features\": [{\"name\": \"sso\", \"enabled\": true}, {\"name\": \"directory_sync\", \"enabled\": false}]}'
  _globals['_ORGANIZATIONSETTINGSFEATURE'].fields_by_name['name']._loaded_options = None
  _globals['_ORGANIZATIONSETTINGSFEATURE'].fields_by_name['name']._serialized_options = b'\222A{2rFeature identifier. Supported values include: \"sso\" (Single Sign-On), \"directory_sync\" (Directory Synchronization)J\005\"sso\"'
  _globals['_ORGANIZATIONSETTINGSFEATURE'].fields_by_name['enabled']._loaded_options = None
  _globals['_ORGANIZATIONSETTINGSFEATURE'].fields_by_name['enabled']._serialized_options = b'\222AW2OWhether the feature is enabled (true) or disabled (false) for this organizationJ\004true'
  _globals['_ORGANIZATIONSETTINGSFEATURE']._loaded_options = None
  _globals['_ORGANIZATIONSETTINGSFEATURE']._serialized_options = b'\222Ar\np*\033Organization Feature Toggle2@Controls the activation state of a specific organization feature\322\001\004name\322\001\007enabled'
  _globals['_UPDATEUSERMANAGEMENTSETTINGSREQUEST'].fields_by_name['organization_id']._loaded_options = None
  _globals['_UPDATEUSERMANAGEMENTSETTINGSREQUEST'].fields_by_name['organization_id']._serialized_options = b'\222A\0312\027ID of the organization.\272H\017r\n\020\001\030 :\004org_\310\001\001'
  _globals['_UPDATEUSERMANAGEMENTSETTINGSREQUEST'].fields_by_name['settings']._loaded_options = None
  _globals['_UPDATEUSERMANAGEMENTSETTINGSREQUEST'].fields_by_name['settings']._serialized_options = b'\222A12/The new values for the setting fields to patch.\272H\003\310\001\001'
  _globals['_UPDATEUSERMANAGEMENTSETTINGSRESPONSE'].fields_by_name['settings']._loaded_options = None
  _globals['_UPDATEUSERMANAGEMENTSETTINGSRESPONSE'].fields_by_name['settings']._serialized_options = b'\222A\0262\024The updated setting.'
  _globals['_GETORGANIZATIONUSERMANAGEMENTSETTINGSREQUEST'].fields_by_name['organization_id']._loaded_options = None
  _globals['_GETORGANIZATIONUSERMANAGEMENTSETTINGSREQUEST'].fields_by_name['organization_id']._serialized_options = b'\222A\0312\027ID of the organization.\272H\017r\n\020\001\030 :\004org_\310\001\001'
  _globals['_GETORGANIZATIONUSERMANAGEMENTSETTINGSRESPONSE'].fields_by_name['settings']._loaded_options = None
  _globals['_GETORGANIZATIONUSERMANAGEMENTSETTINGSRESPONSE'].fields_by_name['settings']._serialized_options = b'\222A 2\036List of organization settings.'
  _globals['_ORGANIZATIONSERVICE']._loaded_options = None
  _globals['_ORGANIZATIONSERVICE']._serialized_options = b'\222AU\n\rOrganizations\022D{{import \"proto/scalekit/v1/organizations/organization_details.md\"}}'
  _globals['_ORGANIZATIONSERVICE'].methods_by_name['CreateOrganization']._loaded_options = None
  _globals['_ORGANIZATIONSERVICE'].methods_by_name['CreateOrganization']._serialized_options = b'\222A\266\t\n\rOrganizations\022\026Create an organization\032\217\001Creates a new organization in your environment. Use this endpoint to add a new tenant that can be configured with various settings and metadataJ\223\001\n\003201\022\213\001\nNReturns the newly created organization with its unique identifier and settings\0229\n7\0325.scalekit.v1.organizations.CreateOrganizationResponsej\344\006\n\rx-codeSamples\022\322\0062\317\006\n\244\001*\241\001\n\026\n\005label\022\r\032\013Node.js SDK\n\024\n\004lang\022\014\032\njavascript\nq\n\006source\022g\032econst organization = await sc.organization.createOrganization(name, {\n  externalId: \'externalId\',\n});\n\325\001*\322\001\n\025\n\005label\022\014\032\nPython SDK\n\020\n\004lang\022\010\032\006python\n\246\001\n\006source\022\233\001\032\230\001options = CreateOrganizationOptions()\noptions.external_id = \"externalId\"\norganization = sc.organization.create_organization(\n  name,\n  options=options\n)\n\307\001*\304\001\n\021\n\005label\022\010\032\006Go SDK\n\014\n\004lang\022\004\032\002go\n\240\001\n\006source\022\225\001\032\222\001organization, err := sc.Organization.CreateOrganization(\n  ctx,\n  name,\n  scalekit.CreateOrganizationOptions{\n    ExternalID: \"externalId\",\n  },\n)\n\203\002*\200\002\n\023\n\005label\022\n\032\010Java SDK\n\016\n\004lang\022\006\032\004java\n\330\001\n\006source\022\315\001\032\312\001CreateOrganization createOrganization = CreateOrganization.newBuilder().setDisplayName(\"Test Org\").build();\n\nOrganization createdOrganization = scalekitClient.organizations().create(createOrganization);\202\265\030\002\030T\202\323\344\223\002%\"\025/api/v1/organizations:\014organization'
  _globals['_ORGANIZATIONSERVICE'].methods_by_name['UpdateOrganization']._loaded_options = None
  _globals['_ORGANIZATIONSERVICE'].methods_by_name['UpdateOrganization']._serialized_options = b'\222A\277\n\n\rOrganizations\022\033Update organization details\032\241\001Updates an organization\'s display name, external ID, or metadata. Requires a valid organization identifier. Region code cannot be modified through this endpoint.J\231\001\n\003200\022\221\001\nTReturns the updated organization with all current details reflected in the response.\0229\n7\0325.scalekit.v1.organizations.UpdateOrganizationResponsej\320\007\n\rx-codeSamples\022\276\0072\273\007\n\320\001*\315\001\n\026\n\005label\022\r\032\013Node.js SDK\n\024\n\004lang\022\014\032\njavascript\n\234\001\n\006source\022\221\001\032\216\001const organization = await sc.organization.updateOrganization(organization_id, {\n  displayName: \'displayName\',\n  externalId: \'externalId\',\n});\n\302\001*\277\001\n\025\n\005label\022\014\032\nPython SDK\n\020\n\004lang\022\010\032\006python\n\223\001\n\006source\022\210\001\032\205\001organization = sc.organization.update_organization(organization_id, {\n  display_name: \"display_name\",\n  external_id: \"external_id\"\n})\n\353\001*\350\001\n\021\n\005label\022\010\032\006Go SDK\n\014\n\004lang\022\004\032\002go\n\304\001\n\006source\022\271\001\032\266\001organization, err := sc.Organization.UpdateOrganization(\n  ctx,\n  organizationId,\n  &scalekit.UpdateOrganization{\n    DisplayName: \"displayName\",\n    ExternalId: \"externalId\",\n  },\n)\n\262\002*\257\002\n\023\n\005label\022\n\032\010Java SDK\n\016\n\004lang\022\006\032\004java\n\207\002\n\006source\022\374\001\032\371\001UpdateOrganization updateOrganization = UpdateOrganization.newBuilder()\n  .setDisplayName(\"Updated Organization Name\")\n  .build();\n\nOrganization updatedOrganizationById = scalekitClient.organizations().updateById(organizationId, updateOrganization);\202\265\030\002\030T\202\323\344\223\002*2\032/api/v1/organizations/{id}:\014organization'
  _globals['_ORGANIZATIONSERVICE'].methods_by_name['GetOrganization']._loaded_options = None
  _globals['_ORGANIZATIONSERVICE'].methods_by_name['GetOrganization']._serialized_options = b'\222A\310\n\n\rOrganizations\022\030Get organization details\032]Retrieves organization details by Scalekit ID, including name, region, metadata, and settingsJ\230\001\n\003200\022\220\001\nVReturns the complete organization object with ID, display name, settings, and metadata\0226\n4\0322.scalekit.v1.organizations.GetOrganizationResponsej\242\010\n\rx-codeSamples\022\220\0102\215\010\n\202\002*\377\001\n\026\n\005label\022\r\032\013Node.js SDK\n\024\n\004lang\022\014\032\njavascript\n\316\001\n\006source\022\303\001\032\300\001const sc = new ScalekitClient(\n  <SCALEKIT_ENVIRONMENT_URL>,\n  <SCALEKIT_CLIENT_ID>,\n  <SCALEKIT_CLIENT_SECRET>\n);\n\nconst organization = await sc.organization.getOrganization(organization_id);\n\352\001*\347\001\n\025\n\005label\022\014\032\nPython SDK\n\020\n\004lang\022\010\032\006python\n\273\001\n\006source\022\260\001\032\255\001sc = ScalekitClient(\n  <SCALEKIT_ENVIRONMENT_URL>,\n  <SCALEKIT_CLIENT_ID>,\n  <SCALEKIT_CLIENT_SECRET>\n)\n\norganization = sc.organization.get_organization(\n  organization_id\n)\n\372\001*\367\001\n\021\n\005label\022\010\032\006Go SDK\n\014\n\004lang\022\004\032\002go\n\323\001\n\006source\022\310\001\032\305\001sc := scalekit.NewScalekitClient(\n  <SCALEKIT_ENVIRONMENT_URL>,\n  <SCALEKIT_CLIENT_ID>,\n  <SCALEKIT_CLIENT_SECRET>\n)\n\norganization, err := sc.Organization.GetOrganization(\n  ctx,\n  organizationId\n)\n\233\002*\230\002\n\023\n\005label\022\n\032\010Java SDK\n\016\n\004lang\022\006\032\004java\n\360\001\n\006source\022\345\001\032\342\001ScalekitClient scalekitClient = new ScalekitClient(\n  \"<SCALEKIT_ENVIRONMENT_URL>\",\n  \"<SCALEKIT_CLIENT_ID>\",\n  \"<SCALEKIT_CLIENT_SECRET>\"\n);\n\nOrganization organization = scalekitClient.organizations().getById(organizationId);\202\265\030\002\030t\202\323\344\223\002\034\022\032/api/v1/organizations/{id}'
  _globals['_ORGANIZATIONSERVICE'].methods_by_name['ListOrganization']._loaded_options = None
  _globals['_ORGANIZATIONSERVICE'].methods_by_name['ListOrganization']._serialized_options = b'\222A\340\010\n\rOrganizations\022\022List organizations\032\240\001Retrieve a paginated list of organizations within your environment. The response includes a `page_token` that can be used to access subsequent pages of results.\"C\n%Learn more about organization listing\022\032https://docs.scalekit.com/Js\n\003200\022l\n0Successfully retrieved the list of organizations\0228\n6\0324.scalekit.v1.organizations.ListOrganizationsResponseJ\033\n\003400\022\024\n\022Invalid page tokenj\300\005\n\rx-codeSamples\022\256\0052\253\005\n\227\001*\224\001\n\026\n\005label\022\r\032\013Node.js SDK\n\024\n\004lang\022\014\032\njavascript\nd\n\006source\022Z\032Xconst organizations = await scalekit.organization.listOrganization({\n  pageSize: 10,\n});\n\300\001*\275\001\n\025\n\005label\022\014\032\nPython SDK\n\020\n\004lang\022\010\032\006python\n\221\001\n\006source\022\206\001\032\203\001options = ListOrganizationOptions()\noptions.page_size = 10\n\norganizations = sc.organization.list_organizations(\n  options=options\n)\n\257\001*\254\001\n\021\n\005label\022\010\032\006Go SDK\n\014\n\004lang\022\004\032\002go\n\210\001\n\006source\022~\032|organizations, err := sc.Organization.ListOrganizations(\n  ctx,\n  &scalekit.ListOrganizationOptions{\n    PageSize: 10,\n  }\n)\n\231\001*\226\001\n\023\n\005label\022\n\032\010Java SDK\n\016\n\004lang\022\006\032\004java\no\n\006source\022e\032cListOrganizationsResponse organizations = scalekitClient.organizations().listOrganizations(10, \"\");\202\265\030\002\030T\202\323\344\223\002\027\022\025/api/v1/organizations'
  _globals['_ORGANIZATIONSERVICE'].methods_by_name['SearchOrganization']._loaded_options = None
  _globals['_ORGANIZATIONSERVICE'].methods_by_name['SearchOrganization']._serialized_options = b'\222A\256\003\n\rOrganizations\022\024Search organizations\032\324\001Searches for organizations in your environment using a query string. The query matches against organization name, ID, or external ID. Returns multiple results when more than one organization matches the criteria.J\257\001\n\003200\022\247\001\niReturns a list of matching organizations and a page token for pagination if there are additional results.\022:\n8\0326.scalekit.v1.organizations.SearchOrganizationsResponse\202\265\030\002\030T\372\322\344\223\002\t\022\007PREVIEW\202\323\344\223\002\036\022\034/api/v1/organizations:search'
  _globals['_ORGANIZATIONSERVICE'].methods_by_name['DeleteOrganization']._loaded_options = None
  _globals['_ORGANIZATIONSERVICE'].methods_by_name['DeleteOrganization']._serialized_options = b'\222A\272\006\n\rOrganizations\022\026Delete an organization\032PRemove an existing organization from the environment using its unique identifierJC\n\003200\022<\n:Organization successfully deleted and no longer accessiblej\371\004\n\rx-codeSamples\022\347\0042\344\004\nw*u\n\026\n\005label\022\r\032\013Node.js SDK\n\024\n\004lang\022\014\032\njavascript\nE\n\006source\022;\0329await sc.organization.deleteOrganization(organizationId);\nm*k\n\025\n\005label\022\014\032\nPython SDK\n\020\n\004lang\022\010\032\006python\n@\n\006source\0226\0324sc.organization.delete_organization(organization_id)\nu*s\n\021\n\005label\022\010\032\006Go SDK\n\014\n\004lang\022\004\032\002go\nP\n\006source\022F\032Derr := sc.Organization.DeleteOrganization(\n  ctx,\n  organizationId\n)\n\202\002*\377\001\n\023\n\005label\022\n\032\010Java SDK\n\016\n\004lang\022\006\032\004java\n\327\001\n\006source\022\314\001\032\311\001ScalekitClient scalekitClient = new ScalekitClient(\n  \"<SCALEKIT_ENVIRONMENT_URL>\",\n  \"<SCALEKIT_CLIENT_ID>\",\n  \"<SCALEKIT_CLIENT_SECRET>\"\n);\n\nscalekitClient.organizations().deleteById(organizationId);\202\265\030\002\030T\202\323\344\223\002\034*\032/api/v1/organizations/{id}'
  _globals['_ORGANIZATIONSERVICE'].methods_by_name['GeneratePortalLink']._loaded_options = None
  _globals['_ORGANIZATIONSERVICE'].methods_by_name['GeneratePortalLink']._serialized_options = b'\222A\347\007\n\rOrganizations\022\032Generate admin portal link\032\302\001Creates a time-limited Admin Portal URL for IT administrators to configure and manage Single Sign-On (SSO) connections within their organization. Generated links expire after 7 days (168 hours).J\237\001\n\003200\022\227\001\nZAdmin Portal link generated successfully. Returns the portal URL and expiration timestamp.\0229\n7\0325.scalekit.v1.organizations.GeneratePortalLinkResponsej\322\004\n\rx-codeSamples\022\300\0042\275\004\n\206\001*\203\001\n\026\n\005label\022\r\032\013Node.js SDK\n\024\n\004lang\022\014\032\njavascript\nS\n\006source\022I\032Gconst link = await sc.organization.generatePortalLink(organization_id);\ny*w\n\025\n\005label\022\014\032\nPython SDK\n\020\n\004lang\022\010\032\006python\nL\n\006source\022B\032@link = sc.organization.generate_portal_link(\n  organization_id\n)\n{*y\n\021\n\005label\022\010\032\006Go SDK\n\014\n\004lang\022\004\032\002go\nV\n\006source\022L\032Jlink, err := sc.Organization.GeneratePortalLink(\n  ctx,\n  organizationId\n)\n\271\001*\266\001\n\023\n\005label\022\n\032\010Java SDK\n\016\n\004lang\022\006\032\004java\n\216\001\n\006source\022\203\001\032\200\001Link portalLink = client\n  .organizations()\n  .generatePortalLink(organizationId, Arrays.asList(Feature.sso, Feature.dir_sync));\202\265\030\002\030T\202\323\344\223\002)\032\'/api/v1/organizations/{id}/portal_links'
  _globals['_ORGANIZATIONSERVICE'].methods_by_name['DeletePortalLink']._loaded_options = None
  _globals['_ORGANIZATIONSERVICE'].methods_by_name['DeletePortalLink']._serialized_options = b'\222A\360\004\n\014Admin Portal\022\022Delete portal link\032)Revokes and deletes an Admin portal link.J)\n\003200\022\"\n Portal link deleted successfullyj\365\003\n\rx-codeSamples\022\343\0032\340\003\n}*{\n\026\n\005label\022\r\032\013Node.js SDK\n\024\n\004lang\022\014\032\njavascript\nK\n\006source\022A\032?await sc.organization.deletePortalLink(organizationId, linkId);\n{*y\n\025\n\005label\022\014\032\nPython SDK\n\020\n\004lang\022\010\032\006python\nN\n\006source\022D\032Bsc.organization.delete_portal_link(\n  organization_id,\n  link_id\n)\n}*{\n\021\n\005label\022\010\032\006Go SDK\n\014\n\004lang\022\004\032\002go\nX\n\006source\022N\032Lerr := sc.Organization.DeletePortalLink(\n  ctx,\n  organizationId,\n  linkId\n)\nc*a\n\023\n\005label\022\n\032\010Java SDK\n\016\n\004lang\022\006\032\004java\n:\n\006source\0220\032.// Hang in there. Coming soon! (Vroom! Vroom!)\202\265\030\002\030P\372\322\344\223\002\t\022\007PREVIEW\202\323\344\223\002)*\'/api/v1/organizations/{id}/portal_links'
  _globals['_ORGANIZATIONSERVICE'].methods_by_name['DeletePortalLinkByID']._loaded_options = None
  _globals['_ORGANIZATIONSERVICE'].methods_by_name['DeletePortalLinkByID']._serialized_options = b'\222Ae\n\014Admin Portal\022\030Delete admin portal link\032)Revokes and deletes an Admin portal link.J\020\n\003200\022\t\n\007Success\202\265\030\002\030T\372\322\344\223\002\t\022\007PREVIEW\202\323\344\223\0023*1/api/v1/organizations/{id}/portal_links/{link_id}'
  _globals['_ORGANIZATIONSERVICE'].methods_by_name['GetPortalLinks']._loaded_options = None
  _globals['_ORGANIZATIONSERVICE'].methods_by_name['GetPortalLinks']._serialized_options = b'\222A\215\006\n\014Admin Portal\022\017Get portal link\032_Returns the Admin portal link if it exists. Use Generate Portal link to create and fetch a linkJG\n\003200\022@\n\007Success\0225\n3\0321.scalekit.v1.organizations.GetPortalLinksResponsej\301\004\n\rx-codeSamples\022\257\0042\254\004\n|*z\n\026\n\005label\022\r\032\013Node.js SDK\n\024\n\004lang\022\014\032\njavascript\nJ\n\006source\022@\032>const links = sc.organization.getPortalLinks(organization_id);\nv*t\n\025\n\005label\022\014\032\nPython SDK\n\020\n\004lang\022\010\032\006python\nI\n\006source\022?\032=links = sc.organization.get_portal_links(\n  organization_id\n)\nx*v\n\021\n\005label\022\010\032\006Go SDK\n\014\n\004lang\022\004\032\002go\nS\n\006source\022I\032Glinks, err := sc.Organization.GetPortalLinks(\n  ctx,\n  organizationId\n)\n\271\001*\266\001\n\023\n\005label\022\n\032\010Java SDK\n\016\n\004lang\022\006\032\004java\n\216\001\n\006source\022\203\001\032\200\001Link portalLink = client\n  .organizations()\n  .generatePortalLink(organizationId, Arrays.asList(Feature.sso, Feature.dir_sync));\202\265\030\002\030P\372\322\344\223\002\t\022\007PREVIEW\202\323\344\223\002)\022\'/api/v1/organizations/{id}/portal_links'
  _globals['_ORGANIZATIONSERVICE'].methods_by_name['UpdateOrganizationSettings']._loaded_options = None
  _globals['_ORGANIZATIONSERVICE'].methods_by_name['UpdateOrganizationSettings']._serialized_options = b'\222A\325\021\n\rOrganizations\022\034Toggle organization settings\032\323\001Updates configuration settings for an organization. Supports modifying SSO configuration, directory synchronization settings, and session parameters. Requires organization ID and the specific settings to update.J\343\001\n\003200\022\333\001\n\240\001Returns the complete organization object with updated settings applied. Contains all organization details including ID, display name, and the modified settings.\0226\n4\0322.scalekit.v1.organizations.GetOrganizationResponseJp\n\003400\022i\ngInvalid request - occurs when the settings payload contains invalid values or unsupported configurationJM\n\003404\022F\nDOrganization not found - the specified organization ID doesn\'t existj\250\014\n\rx-codeSamples\022\226\0142\223\014\n\253\002*\250\002\n\026\n\005label\022\r\032\013Node.js SDK\n\024\n\004lang\022\014\032\njavascript\n\367\001\n\006source\022\354\001\032\351\001const settings = {\n  features: [\n    {\n      name: \'sso\',\n      enabled: true,\n    },\n    {\n      name: \'dir_sync\',\n      enabled: true,\n    },\n  ],\n};\n\nawait sc.organization.updateOrganizationSettings(\'<organization_id>\', settings);\n\325\002*\322\002\n\025\n\005label\022\014\032\nPython SDK\n\020\n\004lang\022\010\032\006python\n\246\002\n\006source\022\233\002\032\230\002settings = [\n        {\n            \"name\": \"sso\",\n            \"enabled\": true\n        },\n        {\n            \"name\": \"dir_sync\",\n            \"enabled\": true\n        }\n    ]\n\nsc.organization.update_organization_settings(\n  organization_id=\'<organization_id>\', settings=settings\n)\n\277\002*\274\002\n\021\n\005label\022\010\032\006Go SDK\n\014\n\004lang\022\004\032\002go\n\230\002\n\006source\022\215\002\032\212\002settings := OrganizationSettings{\n\t\tFeatures: []Feature{\n\t\t\t{\n\t\t\t\tName:    \"sso\",\n\t\t\t\tEnabled: true,\n\t\t\t},\n\t\t\t{\n\t\t\t\tName:    \"dir_sync\",\n\t\t\t\tEnabled: true,\n\t\t\t},\n\t\t},\n\t}\n\norganization,err := sc.Organization().UpdateOrganizationSettings(ctx, organizationId, settings)\n\310\004*\305\004\n\023\n\005label\022\n\032\010Java SDK\n\016\n\004lang\022\006\032\004java\n\235\004\n\006source\022\222\004\032\217\004OrganizationSettingsFeature featureSSO = OrganizationSettingsFeature.newBuilder()\n                .setName(\"sso\")\n                .setEnabled(true)\n                .build();\n\nOrganizationSettingsFeature featureDirectorySync = OrganizationSettingsFeature.newBuilder()\n                .setName(\"dir_sync\")\n                .setEnabled(true)\n                .build();\n\nupdatedOrganization = scalekitClient.organizations()\n                .updateOrganizationSettings(organization.getId(), List.of(featureSSO, featureDirectorySync));\202\265\030\002\030T\202\323\344\223\002/2#/api/v1/organizations/{id}/settings:\010settings'
  _globals['_ORGANIZATIONSERVICE'].methods_by_name['CreateOrganizationSessionSettings']._loaded_options = None
  _globals['_ORGANIZATIONSERVICE'].methods_by_name['CreateOrganizationSessionSettings']._serialized_options = b'\222A\335\003\n\rOrganizations\022$Create organization session settings\032\371\001Defines session timeout policies for an organization, including absolute and idle timeout durations. This endpoint is used to configure session lifetimes and enhance security by automatically logging out users after a specified period of inactivity.J\251\001\n\003201\022\241\001\nUSession settings created successfully. Returns the newly configured session policies.\022H\nF\032D.scalekit.v1.organizations.CreateOrganizationSessionSettingsResponse\202\265\030\002\030T\372\322\344\223\002\t\022\007PREVIEW\202\323\344\223\002-\"+/api/v1/organizations/{id}/session-settings'
  _globals['_ORGANIZATIONSERVICE'].methods_by_name['GetOrganizationSessionSettings']._loaded_options = None
  _globals['_ORGANIZATIONSERVICE'].methods_by_name['GetOrganizationSessionSettings']._serialized_options = b'\222A\301\002\n\rOrganizations\022!Get organization session settings\032\204\001Retrieves the currently configured session timeout policies for a specific organization, including absolute and idle timeout values.J\205\001\n\003200\022~\n5Successfully retrieved organization session settings.\022E\nC\032A.scalekit.v1.organizations.GetOrganizationSessionSettingsResponse\202\265\030\002\030T\372\322\344\223\002\t\022\007PREVIEW\202\323\344\223\002-\022+/api/v1/organizations/{id}/session-settings'
  _globals['_ORGANIZATIONSERVICE'].methods_by_name['UpdateOrganizationSessionSettings']._loaded_options = None
  _globals['_ORGANIZATIONSERVICE'].methods_by_name['UpdateOrganizationSessionSettings']._serialized_options = b'\222A\377\002\n\rOrganizations\022$Update organization session settings\032\243\001Modifies the session timeout policies for an organization. Use this to adjust the absolute and idle session timeout durations to enforce different security levels.J\241\001\n\003200\022\231\001\nMSession settings updated successfully. Returns the modified session policies.\022H\nF\032D.scalekit.v1.organizations.UpdateOrganizationSessionSettingsResponse\202\265\030\002\030T\372\322\344\223\002\t\022\007PREVIEW\202\323\344\223\002?2+/api/v1/organizations/{id}/session-settings:\020session_settings'
  _globals['_ORGANIZATIONSERVICE'].methods_by_name['DeleteOrganizationSessionSettings']._loaded_options = None
  _globals['_ORGANIZATIONSERVICE'].methods_by_name['DeleteOrganizationSessionSettings']._serialized_options = b'\222A\375\001\n\rOrganizations\022$Delete organization session settings\032\207\001Resets an organization\'s session timeout policies to the default settings, removing any custom absolute or idle timeout configurations.J<\n\003200\0225\n3Organization session settings deleted successfully.\202\265\030\002\030T\372\322\344\223\002\t\022\007PREVIEW\202\323\344\223\002-*+/api/v1/organizations/{id}/session-settings'
  _globals['_ORGANIZATIONSERVICE'].methods_by_name['UpdateUserManagementSettings']._loaded_options = None
  _globals['_ORGANIZATIONSERVICE'].methods_by_name['UpdateUserManagementSettings']._serialized_options = b'\222A\215\002\n\rOrganizations\022 Update organization user setting\0324Updates user management settings for an organizationJw\n\003200\022p\n)Returns the updated organization setting.\022C\nA\032?.scalekit.v1.organizations.UpdateUserManagementSettingsResponseJ+\n\003404\022$\n\"Organization or setting not found.\202\265\030\002\030t\372\322\344\223\002\t\022\007PREVIEW\202\323\344\223\002D2?/api/v1/organizations/{organization_id}/settings/usermanagement:\001*'
  _globals['_ORGANIZATIONSERVICE'].methods_by_name['GetOrganizationUserManagementSetting']._loaded_options = None
  _globals['_ORGANIZATIONSERVICE'].methods_by_name['GetOrganizationUserManagementSetting']._serialized_options = b'\222A\260\002\n\rOrganizations\022(Get organization user management setting\032CRetrieves the user management settings for a specific organization.J\202\001\n\003200\022{\n+Returns the requested organization setting.\022L\nJ\032H.scalekit.v1.organizations.GetOrganizationUserManagementSettingsResponseJ+\n\003404\022$\n\"Organization or setting not found.\202\265\030\002\030t\372\322\344\223\002\t\022\007PREVIEW\202\323\344\223\002A\022?/api/v1/organizations/{organization_id}/settings/usermanagement'
  _globals['_FEATURE']._serialized_start=16112
  _globals['_FEATURE']._serialized_end=16194
  _globals['_CREATEORGANIZATIONREQUEST']._serialized_start=533
  _globals['_CREATEORGANIZATIONREQUEST']._serialized_end=708
  _globals['_CREATEORGANIZATIONRESPONSE']._serialized_start=711
  _globals['_CREATEORGANIZATIONRESPONSE']._serialized_end=896
  _globals['_CREATEORGANIZATION']._serialized_start=899
  _globals['_CREATEORGANIZATION']._serialized_end=1571
  _globals['_CREATEORGANIZATION_METADATAENTRY']._serialized_start=1496
  _globals['_CREATEORGANIZATION_METADATAENTRY']._serialized_end=1555
  _globals['_ORGANIZATION']._serialized_start=1574
  _globals['_ORGANIZATION']._serialized_end=2701
  _globals['_ORGANIZATION_METADATAENTRY']._serialized_start=1496
  _globals['_ORGANIZATION_METADATAENTRY']._serialized_end=1555
  _globals['_UPDATEORGANIZATIONREQUEST']._serialized_start=2704
  _globals['_UPDATEORGANIZATIONREQUEST']._serialized_end=3184
  _globals['_UPDATEORGANIZATION']._serialized_start=3187
  _globals['_UPDATEORGANIZATION']._serialized_end=3924
  _globals['_UPDATEORGANIZATION_METADATAENTRY']._serialized_start=1496
  _globals['_UPDATEORGANIZATION_METADATAENTRY']._serialized_end=1555
  _globals['_UPDATEORGANIZATIONRESPONSE']._serialized_start=3927
  _globals['_UPDATEORGANIZATIONRESPONSE']._serialized_end=4067
  _globals['_GETORGANIZATIONREQUEST']._serialized_start=4070
  _globals['_GETORGANIZATIONREQUEST']._serialized_end=4433
  _globals['_GETORGANIZATIONRESPONSE']._serialized_start=4436
  _globals['_GETORGANIZATIONRESPONSE']._serialized_end=4575
  _globals['_LISTORGANIZATIONSREQUEST']._serialized_start=4578
  _globals['_LISTORGANIZATIONSREQUEST']._serialized_end=5314
  _globals['_LISTORGANIZATIONSRESPONSE']._serialized_start=5317
  _globals['_LISTORGANIZATIONSRESPONSE']._serialized_end=5865
  _globals['_SEARCHORGANIZATIONSREQUEST']._serialized_start=5868
  _globals['_SEARCHORGANIZATIONSREQUEST']._serialized_end=6547
  _globals['_SEARCHORGANIZATIONSRESPONSE']._serialized_start=6550
  _globals['_SEARCHORGANIZATIONSRESPONSE']._serialized_end=6769
  _globals['_DELETEORGANIZATIONREQUEST']._serialized_start=6772
  _globals['_DELETEORGANIZATIONREQUEST']._serialized_end=7073
  _globals['_GENERATEPORTALLINKREQUEST']._serialized_start=7076
  _globals['_GENERATEPORTALLINKREQUEST']._serialized_end=7667
  _globals['_GETPORTALLINKREQUEST']._serialized_start=7669
  _globals['_GETPORTALLINKREQUEST']._serialized_end=7771
  _globals['_DELETEPORTALLINKREQUEST']._serialized_start=7773
  _globals['_DELETEPORTALLINKREQUEST']._serialized_end=7878
  _globals['_DELETEPORTALLINKBYIDREQUEST']._serialized_start=7881
  _globals['_DELETEPORTALLINKBYIDREQUEST']._serialized_end=8071
  _globals['_LINK']._serialized_start=8074
  _globals['_LINK']._serialized_end=8508
  _globals['_GENERATEPORTALLINKRESPONSE']._serialized_start=8511
  _globals['_GENERATEPORTALLINKRESPONSE']._serialized_end=8789
  _globals['_GETPORTALLINKSRESPONSE']._serialized_start=8791
  _globals['_GETPORTALLINKSRESPONSE']._serialized_end=8895
  _globals['_UPDATEORGANIZATIONSETTINGSREQUEST']._serialized_start=8898
  _globals['_UPDATEORGANIZATIONSETTINGSREQUEST']._serialized_end=9426
  _globals['_UPDATEORGANIZATIONSESSIONSETTINGSREQUEST']._serialized_start=9429
  _globals['_UPDATEORGANIZATIONSESSIONSETTINGSREQUEST']._serialized_end=10051
  _globals['_UPDATEORGANIZATIONSESSIONSETTINGSRESPONSE']._serialized_start=10054
  _globals['_UPDATEORGANIZATIONSESSIONSETTINGSRESPONSE']._serialized_end=10568
  _globals['_ORGANIZATIONUSERMANAGEMENTSETTINGS']._serialized_start=10571
  _globals['_ORGANIZATIONUSERMANAGEMENTSETTINGS']._serialized_end=11274
  _globals['_ORGANIZATIONSESSIONSETTINGS']._serialized_start=11277
  _globals['_ORGANIZATIONSESSIONSETTINGS']._serialized_end=12218
  _globals['_GETORGANIZATIONSESSIONSETTINGSREQUEST']._serialized_start=12221
  _globals['_GETORGANIZATIONSESSIONSETTINGSREQUEST']._serialized_end=12607
  _globals['_CREATEORGANIZATIONSESSIONSETTINGSREQUEST']._serialized_start=12610
  _globals['_CREATEORGANIZATIONSESSIONSETTINGSREQUEST']._serialized_end=13003
  _globals['_CREATEORGANIZATIONSESSIONSETTINGSRESPONSE']._serialized_start=13006
  _globals['_CREATEORGANIZATIONSESSIONSETTINGSRESPONSE']._serialized_end=13506
  _globals['_GETORGANIZATIONSESSIONSETTINGSRESPONSE']._serialized_start=13509
  _globals['_GETORGANIZATIONSESSIONSETTINGSRESPONSE']._serialized_end=14006
  _globals['_DELETEORGANIZATIONSESSIONSETTINGSREQUEST']._serialized_start=14009
  _globals['_DELETEORGANIZATIONSESSIONSETTINGSREQUEST']._serialized_end=14407
  _globals['_ORGANIZATIONSETTINGS']._serialized_start=14410
  _globals['_ORGANIZATIONSETTINGS']._serialized_end=14936
  _globals['_ORGANIZATIONSETTINGSFEATURE']._serialized_start=14939
  _globals['_ORGANIZATIONSETTINGSFEATURE']._serialized_end=15354
  _globals['_UPDATEUSERMANAGEMENTSETTINGSREQUEST']._serialized_start=15357
  _globals['_UPDATEUSERMANAGEMENTSETTINGSREQUEST']._serialized_end=15635
  _globals['_UPDATEUSERMANAGEMENTSETTINGSRESPONSE']._serialized_start=15638
  _globals['_UPDATEUSERMANAGEMENTSETTINGSRESPONSE']._serialized_end=15794
  _globals['_GETORGANIZATIONUSERMANAGEMENTSETTINGSREQUEST']._serialized_start=15797
  _globals['_GETORGANIZATIONUSERMANAGEMENTSETTINGSREQUEST']._serialized_end=15932
  _globals['_GETORGANIZATIONUSERMANAGEMENTSETTINGSRESPONSE']._serialized_start=15935
  _globals['_GETORGANIZATIONUSERMANAGEMENTSETTINGSRESPONSE']._serialized_end=16110
  _globals['_ORGANIZATIONSERVICE']._serialized_start=16198
  _globals['_ORGANIZATIONSERVICE']._serialized_end=32922
# @@protoc_insertion_point(module_scope)



from typing import Optional, Any
from google.protobuf.json_format import MessageToJson

from scalekit.core import CoreClient
from scalekit.utils.directory import DirUser, ListDirUsersResponse, DirGroup, ListDirGroupsResponse

from scalekit.v1.directories.directories_pb2 import *
from scalekit.v1.directories.directories_pb2_grpc import DirectoryServiceStub


class DirectoryClient:
    """ Class definition for Directory Client """

    def __init__(self, core_client: CoreClient):
        """
        Initializer for Directory Client

        :param core_client    : CoreClient Object
        :type                 : ``` obj ```

        :returns
            None
        """
        self.core_client = core_client
        self.directory_service = DirectoryServiceStub(
            self.core_client.grpc_secure_channel
        )

    def get_directory(
            self,
            organization_id: str,
            directory_id: str,
    ) -> GetDirectoryResponse:
        """
        Method to get directory based on given organization and directory id

        :param organization_id   :     Organization id
        :type                    :     ``` str ```
        :param directory_id      :     directory id
        :type                    :     ``` str ```

        :returns:
            Get Directory Response
        """
        return self.core_client.grpc_exec(
            self.directory_service.GetDirectory.with_call,
            GetDirectoryRequest(
                id=directory_id,
                organization_id=organization_id,
            ),
        )

    def list_directories(self, organization_id) -> ListDirectoriesResponse:
        """
        Method to list directories for given organization id

        :param organization_id  : org id to fetch directory list
        :type                   : ``` str ```

        :returns:
             list of directories
        """
        return self.core_client.grpc_exec(
            self.directory_service.ListDirectories.with_call,
            ListDirectoriesRequest(organization_id=organization_id),
        )

    def list_directory_users(
            self,
            organization_id: str,
            directory_id: str,
            page_size: Optional[int] = None,
            page_token: Optional[str] = None,
            include_detail: Optional[bool] = None,
            updated_after: Optional[str] = None
    ) -> tuple[ListDirUsersResponse, Any]:
        """
        Method to fetch list of directory users based on given organization and directory id

        :param organization_id   :     Organization id
        :type                    :     ``` str ```
        :param directory_id      :     directory id
        :type                    :     ``` str ```
        :param page_size         :     page size for org list fetch
        :type                    :     ``` int ```
        :param page_token        :     page token for org list fetch
        :type                    :     ``` str ```
        :param include_detail     :     param to include detailed data
        :type                    :     ``` bool ```
        :param updated_after      :     param to get updated after detail
        :type                    :     ``` str ```

        :returns:
             list of directory users
        """
        response = self.core_client.grpc_exec(
            self.directory_service.ListDirectoryUsers.with_call,
            ListDirectoryUsersRequest(
                organization_id=organization_id,
                directory_id=directory_id,
                page_size=page_size,
                page_token=page_token,
                include_detail=include_detail,
                updated_after=updated_after
            ),
        )

        user_response = (ListDirUsersResponse(), response[1])
        for user in response[0].users:
            dir_user = DirUser()
            dir_user.id = user.id
            dir_user.email = user.email
            dir_user.preferred_username = user.preferred_username
            dir_user.given_name = user.given_name
            dir_user.family_name = user.family_name
            dir_user.updated_at = user.updated_at
            dir_user.emails = user.emails
            dir_user.groups = user.groups
            dir_user.user_detail = MessageToJson(user.user_detail)

            if not hasattr(user_response[0], 'users'):
                user_response[0].users = [dir_user]
            else:
                user_response[0].users.append(dir_user)
            user_response[0].total_size = response[0].total_size
            user_response[0].next_page_token = response[0].next_page_token
            user_response[0].prev_page_token = response[0].prev_page_token

        return user_response

    def list_directory_groups(
            self,
            organization_id: str,
            directory_id: str,
            page_size: Optional[int] = None,
            page_token: Optional[str] = None,
            include_detail: Optional[bool] = None,
            updated_after: Optional[str] = None
    ) -> tuple[ListDirGroupsResponse, Any]:
        """
        Method to fetch list of directory groups based on given organization and directory id

        :param organization_id   :     Organization id
        :type                    :     ``` str ```
        :param directory_id      :     directory id
        :type                    :     ``` str ```
        :param page_size         :     page size for org list fetch
        :type                    :     ``` int ```
        :param page_token        :     page token for org list fetch
        :type                    :     ``` str ```
        :param include_detail     :     param to include detailed data
        :type                    :     ``` bool ```
        :param updated_after      :     param to get updated after detail
        :type                    :     ``` str ```

        :returns:
             list of directory users
        """
        response = self.core_client.grpc_exec(
            self.directory_service.ListDirectoryGroups.with_call,
            ListDirectoryGroupsRequest(
                organization_id=organization_id,
                directory_id=directory_id,
                page_size=page_size,
                page_token=page_token,
                include_detail=include_detail,
                updated_after=updated_after
            ),
        )

        group_response = (ListDirGroupsResponse(), response[1])
        for group in response[0].groups:
            dir_group = DirGroup()
            dir_group.id = group.id
            dir_group.display_name = group.display_name
            dir_group.total_users = group.total_users
            dir_group.updated_at = group.updated_at
            dir_group.group_detail = MessageToJson(group.group_detail)

            if not hasattr(group_response, 'users'):
                group_response[0].groups = [dir_group]
            else:
                group_response[0].groups.append(dir_group)

            group_response[0].total_size = response[0].total_size
            group_response[0].next_page_token = response[0].next_page_token
            group_response[0].prev_page_token = response[0].prev_page_token

        return group_response

    def enable_directory(self, organization_id: str, directory_id: str) -> ToggleDirectoryResponse:
        """
        Method to enable directory based on given organization and directory id

        :param organization_id   :     Organization id
        :type                    :     ``` str ```
        :param directory_id      :     directory id
        :type                    :     ``` str ```

        :returns:
             Toggle Directory Response
        """
        return self.core_client.grpc_exec(
            self.directory_service.EnableDirectory.with_call,
            ToggleDirectoryRequest(organization_id=organization_id, id=directory_id),
        )

    def disable_directory(self, organization_id: str, directory_id: str) -> ToggleDirectoryResponse:
        """
        Method to disable directory based on given organization and directory id

        :param organization_id   :     Organization id
        :type                    :     ``` str ```
        :param directory_id      :     directory id
        :type                    :     ``` str ```

        :returns:
             Toggle Directory Response
        """
        return self.core_client.grpc_exec(
            self.directory_service.DisableDirectory.with_call,
            ToggleDirectoryRequest(organization_id=organization_id, id=directory_id),
        )

    def get_primary_directory_by_organization_id(self, organization_id: str):
        """
        Method to get primary directory based on given organization id

        :param organization_id   :     Organization id
        :type                    :     ``` str ```

        :returns:
            Primary directory
        """
        response = self.core_client.grpc_exec(
            self.directory_service.ListDirectories.with_call,
            ListDirectoriesRequest(organization_id=organization_id),
        )

        if response[0].directories:
            return response[0].directories[0]
        else:
            raise Exception("Directory does not exist for given Organization Id.")

    def create_directory(self, organization_id: str, directory: CreateDirectory) -> CreateDirectoryResponse:
        """
        Method to create directory based on given organization id

        :param organization_id   :     Organization id to create directory for
        :type                    :     ``` str ```
        :param directory         :     CreateDirectory object with expected values for dir creation
        :type                    :     ``` obj ```

        :returns:
            Create Directory Response
        """
        return self.core_client.grpc_exec(
            self.directory_service.CreateDirectory.with_call,
            CreateDirectoryRequest(organization_id=organization_id, directory=directory),
        )

    def delete_directory(self, organization_id: str, directory_id: str):
        """
        Method to delete directory based on given organization and directory id

        :param organization_id   :     Organization id to delete directory for
        :type                    :     ``` str ```
        :param directory_id      :     Directory id for directory to be deleted
        :type                    :     ``` str ```

        :returns:
            None
        """
        return self.core_client.grpc_exec(
            self.directory_service.DeleteDirectory.with_call,
            DeleteDirectoryRequest(organization_id=organization_id, id=directory_id),
        )
